!******************************************************************************!
!                                                                              !
!    class_vertices.f90                                                        !
!    is part of RECOLA2 (REcursive Computation of One Loop Amplitudes)2        !
!                                                                              !
!    Copyright (C) 2016-2018 Ansgar Denner, Jean-Nicolas Lang and              !
!                            Sandro Uccirati                                   !
!                                                                              !
!    RECOLA2 is licenced under the GNU GPL version 3,                          !
!    see COPYING for details.                                                  !
!                                                                              !
!******************************************************************************!
!                                                           .---.              !
!                                                          /  .  \             !
!                                                         |\_/|   |            !
!                                                         |   |  /|            !
!          .----------------------------------------------------' |            !
!         /  .-.   class_vertices.f90                             |            !
!        |  /   \  This code was generated with REPT1L.           |            !
!        | |\_.  | Change this file and you get what you deserve. |            !
!        |\|  | /| Author: J.-N. Lang                             |            !
!        | `---' | UFO date: 23.11.2018                           |            !
!        |       | UFO version: 1.1                               |            !
!        |       | Generation date: 2018-11-28 06:18             /             !
!        |       |----------------------------------------------'              !
!        \       |                                                             !
!         \     /                                                              !
!          `---'                                                               !
!******************************************************************************!
module class_vertices
  use fill_couplings
  use class_particles
  use class_ctparameters
  use fill_ctparameters, only: init_CTparameters_mdl
  use particle_keys, only: createParticleConfig
  use dictionary, only: dict,dict_get_value,dict_init
  use constants_mdl, only: Nc
  implicit none
  save

  interface get_vertex_mdl
    module procedure get_vertex3_mdl, get_vertex4_mdl, get_vertexN_mdl
  end interface

  type Branch
    integer :: lorentz_id
    integer :: perm
    integer, allocatable :: couplings(:)
    integer, dimension(n_orders) :: coupling_order
    integer :: color_id
    integer :: colorfac_id
    ! Propagator extension (only supported for massive vectors)
    ! 0: Usual propagator
    ! 1: Rxi-propagator part with pole @ M_V^2
    ! 2: Rxi-propagator part with pole @ \xi*M_V^2
    integer :: pext
  end type

  type Vertex
    type(Branch), allocatable :: branch(:)
    type(Branch), allocatable :: branchCT(:)
    type(Branch), allocatable :: branchR2(:)
  end type

  logical :: vertices_init = .false.
  logical :: vertices_filled = .false.
    interface createCurrent
      module procedure createCurrent2, createCurrent3, createCurrent4,         &
      createCurrent5, createCurrent6, createCurrent7, createCurrent8
    end interface 
  integer, parameter :: n_vertices = 1675
  type(Vertex) :: vertices(0:n_vertices-1)

  ! Defines the maximum allowed number of legs participating at a vertex
  integer, parameter :: max_leg_multiplicity = 4

  integer, parameter :: FFaS0 = 1
  integer, parameter :: FFaS1 = 2
  integer, parameter :: FFaS2 = 3
  integer, parameter :: FFaV0 = 4
  integer, parameter :: FFaV1 = 5
  integer, parameter :: SVVS0 = 6
  integer, parameter :: VVS0 = 7
  integer, parameter :: UUaS0 = 8
  integer, parameter :: UUaV0 = 9
  integer, parameter :: SUUa0 = 10
  integer, parameter :: VVSS0 = 11
  integer, parameter :: UaSU0 = 12
  integer, parameter :: VFaF0 = 13
  integer, parameter :: VFaF1 = 14
  integer, parameter :: VVV0 = 15
  integer, parameter :: FSFa0 = 16
  integer, parameter :: FSFa1 = 17
  integer, parameter :: FSFa2 = 18
  integer, parameter :: VVVV0 = 19
  integer, parameter :: VVVV1 = 20
  integer, parameter :: VVVV2 = 21
  integer, parameter :: VVVV3 = 22
  integer, parameter :: VVVV4 = 23
  integer, parameter :: FaVF0 = 24
  integer, parameter :: FaVF1 = 25
  integer, parameter :: UaVU0 = 26
  integer, parameter :: FaF0 = 27
  integer, parameter :: FaF1 = 28
  integer, parameter :: FaF2 = 29
  integer, parameter :: VSVS0 = 30
  integer, parameter :: FVFa0 = 31
  integer, parameter :: FVFa1 = 32
  integer, parameter :: VUaU0 = 33
  integer, parameter :: USUa0 = 34
  integer, parameter :: VV0 = 35
  integer, parameter :: VV1 = 36
  integer, parameter :: VV2 = 37
  integer, parameter :: VV3 = 38
  integer, parameter :: SVSV0 = 39
  integer, parameter :: FaFS0 = 40
  integer, parameter :: FaFS1 = 41
  integer, parameter :: FaFS2 = 42
  integer, parameter :: FaFV0 = 43
  integer, parameter :: FaFV1 = 44
  integer, parameter :: SSSS0 = 45
  integer, parameter :: VS0 = 46
  integer, parameter :: VS1 = 47
  integer, parameter :: SFFa0 = 48
  integer, parameter :: SFFa1 = 49
  integer, parameter :: SFFa2 = 50
  integer, parameter :: VUUa0 = 51
  integer, parameter :: SFaF0 = 52
  integer, parameter :: SFaF1 = 53
  integer, parameter :: SFaF2 = 54
  integer, parameter :: SVV0 = 55
  integer, parameter :: FaSF0 = 56
  integer, parameter :: FaSF1 = 57
  integer, parameter :: FaSF2 = 58
  integer, parameter :: SVS0 = 59
  integer, parameter :: FFa0 = 60
  integer, parameter :: FFa1 = 61
  integer, parameter :: FFa2 = 62
  integer, parameter :: VSS0 = 63
  integer, parameter :: VSV0 = 64
  integer, parameter :: SS0 = 65
  integer, parameter :: SS1 = 66
  integer, parameter :: SS2 = 67
  integer, parameter :: SS3 = 68
  integer, parameter :: SSVV0 = 69
  integer, parameter :: SSV0 = 70
  integer, parameter :: SV0 = 71
  integer, parameter :: SV1 = 72
  integer, parameter :: SSS0 = 73
  integer, parameter :: UVUa0 = 74
  integer, parameter :: VSSV0 = 75
  integer, parameter :: UaUS0 = 76
  integer, parameter :: VFFa0 = 77
  integer, parameter :: VFFa1 = 78
  integer, parameter :: SUaU0 = 79
  integer, parameter :: UaUV0 = 80
  complex(dp), parameter :: c1 = cmplx(1d0, 0d0, kind=dp)
  character(len=20), parameter :: c1f = "1"
  complex(dp), parameter :: c2 = cmplx(-sq2/(2d0*Nc), 0d0, kind=dp)
  character(len=20), parameter :: c2f = "-sq2/(2*Nc)"
  complex(dp), parameter :: c3 = cmplx(sq2/2d0, 0d0, kind=dp)
  character(len=20), parameter :: c3f = "sq2/2"
  complex(dp), parameter :: c4 = cmplx(0d0, sq2/2d0, kind=dp)
  character(len=20), parameter :: c4f = "i_*sq2/2"
  complex(dp), parameter :: c5 = cmplx(0d0, -sq2/2d0, kind=dp)
  character(len=20), parameter :: c5f = "-i_*sq2/2"
  complex(dp), parameter :: c6 = cmplx(-1d0/2d0, 0d0, kind=dp)
  character(len=20), parameter :: c6f = "-1/2"
  complex(dp), parameter :: c7 = cmplx(1d0/2d0, 0d0, kind=dp)
  character(len=20), parameter :: c7f = "1/2"
  complex(dp), parameter :: c8 = cmplx(-1d0/Nc, 0d0, kind=dp)
  character(len=20), parameter :: c8f = "-1/Nc"
  complex(dp), dimension(1:8) :: colorcoeffs = (/c1, c2, c3, c4, c5, c6, c7, c8&
                                               /)
  character(len=20), dimension(1:8) :: colorcoeffs_form = (/c1f, c2f, c3f, c4f &
                 , c5f, c6f, c7f, c8f/)
  integer, dimension(1:80) :: lorentz_rank = (/0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0 &
                                             , 0, 1, 1, 1, 1, 1, 1, 0, 0, 0, -1&
                                             , -1, 1, 1, 1, -1, -1, -1, 0, 1, 1&
                                             , 1, 0, -1, -1, -1, -1, 0, 0, 0, 0&
                                             , 0, 0, 0, -1, -1, 1, 1, 1, 1, 1, &
                                             1, 1, 0, 1, 1, 1, 1, -1, -1, -1, 1&
                                             , 0, -1, -1, -1, -1, 0, 1, -1, -1 &
                                             , 0, 1, 0, 0, 1, 1, 0, 1/)
  integer, dimension(1:80) :: recola_base = (/0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, &
                                            0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0 &
                                            , 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, &
                                            0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0 &
                                            , 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, &
                                            0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0 &
                                            , 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0/)
  integer, dimension(1:80) :: propagator_extension = (/0, 0, 0, 0, 0, 0, 0, 0, &
                                                     0, 0, 0, 0, 0, 0, 0, 0, 0 &
                                                     , 0, 0, 0, 0, 0, 0, 0, 0, &
                                                     0, 0, 0, 0, 0, 0, 0, 0, 0 &
                                                     , 0, 0, 0, 0, 0, 0, 0, 0, &
                                                     0, 0, 0, 0, 0, 0, 0, 0, 0 &
                                                     , 0, 0, 0, 0, 0, 0, 0, 0, &
                                                     0, 0, 0, 0, 0, 0, 0, 0, 0 &
                                                     , 0, 0, 0, 0, 0, 0, 0, 0, &
                                                     0, 0, 0, 0/)
  character(len=*), parameter :: model_timestamp = "Tue Nov 27 20:21:52 2018"

  contains
    function get_timestamp_mdl() result(ret_timestamp)
      character(len=len(model_timestamp)) :: ret_timestamp
      ret_timestamp = model_timestamp
    end function get_timestamp_mdl

    function get_lorentz_rank_mdl(l_id) result(ret_lorentz_rank)
      integer, intent(in) :: l_id
      integer :: ret_lorentz_rank
      ret_lorentz_rank = lorentz_rank(l_id)
    end function get_lorentz_rank_mdl

    function get_propagator_extension_mdl(l_id) result(ret_pext)
      integer, intent(in) :: l_id
      integer :: ret_pext
      ret_pext = propagator_extension(l_id)
    end function get_propagator_extension_mdl

    function get_max_leg_multiplicity_mdl() result(ret_max_leg_multiplicity)
      integer :: ret_max_leg_multiplicity
      ret_max_leg_multiplicity = max_leg_multiplicity
    end function get_max_leg_multiplicity_mdl

    function is_model_init_mdl() result(ret_init)
      logical :: ret_init
      ret_init = vertices_init
    end function is_model_init_mdl

    function is_model_filled_mdl() result(ret_init)
      logical :: ret_init
      ret_init = vertices_filled
    end function is_model_filled_mdl

    subroutine get_vertex3_mdl(p1, p2, p3, vertex_ret)
      integer, intent(out) :: vertex_ret
      integer, intent(in)  :: p1, p2, p3
      integer(kind=8)      :: config
      integer              :: address
      logical              :: found_vertex

      call createParticleConfig(p1, p2, p3, config)
      call dict(config, 1, address, found_vertex, 0)
      if(found_vertex) then
        vertex_ret = dict_get_value(address)
      else
        vertex_ret = -1
      end if

    end subroutine get_vertex3_mdl

    subroutine get_vertex4_mdl(p1, p2, p3, p4, vertex_ret)
      integer, intent(out) :: vertex_ret
      integer, intent(in)  :: p1, p2, p3, p4
      integer(kind=8)      :: config
      integer              :: address
      logical              :: found_vertex

      call createParticleConfig(p1, p2, p3, p4, config)
      call dict(config, 1, address, found_vertex, 0)
      if(found_vertex) then
        vertex_ret = dict_get_value(address)
      else
        vertex_ret = -1
      end if
    end subroutine get_vertex4_mdl

    subroutine get_vertexN_mdl(particles, particleOut, vertex_ret)
      integer, intent(out)              :: vertex_ret
      integer, dimension(:), intent(in) :: particles
      integer, intent(in)               :: particleOut
      integer(kind=8)                   :: config
      integer                           :: address
      logical                           :: found_vertex

      call createParticleConfig(particles, particleOut, config)
      call dict(config, 1, address, found_vertex, 0)
      if(found_vertex) then
        vertex_ret = dict_get_value(address)
      else
        vertex_ret = -1
      end if

    end subroutine get_vertexN_mdl

    subroutine av(vid,bid,cid,cfid,pext,lid,perm,co,cop)
      integer, intent(in) :: vid,bid,cid,cfid,pext,lid,perm
      integer, dimension(0:), intent(in) :: co, cop
      integer scop,i
      vertices(vid)%branch(bid)%color_id = cid
      vertices(vid)%branch(bid)%colorfac_id = cfid
      vertices(vid)%branch(bid)%pext = pext
      vertices(vid)%branch(bid)%lorentz_id = lid
      vertices(vid)%branch(bid)%perm = perm
      vertices(vid)%branch(bid)%coupling_order = co
      scop = size(cop)
      allocate(vertices(vid)%branch(bid)%couplings(0:scop-1))
      do i = 0, scop-1
        vertices(vid)%branch(bid)%couplings(i) = cop(i)
      end do
    end subroutine av

    subroutine avCT(vid,bid,cid,cfid,pext,lid,perm,co,cop)
      integer, intent(in) :: vid,bid,cid,cfid,pext,lid,perm
      integer, dimension(0:), intent(in) :: co, cop
      integer scop,i
      vertices(vid)%branchCT(bid)%color_id = cid
      vertices(vid)%branchCT(bid)%colorfac_id = cfid
      vertices(vid)%branchCT(bid)%pext = pext
      vertices(vid)%branchCT(bid)%lorentz_id = lid
      vertices(vid)%branchCT(bid)%perm = perm
      vertices(vid)%branchCT(bid)%coupling_order = co
      scop = size(cop)
      allocate(vertices(vid)%branchCT(bid)%couplings(0:scop-1))
      do i = 0, scop-1
        vertices(vid)%branchCT(bid)%couplings(i) = cop(i)
      end do
    end subroutine avCT

    subroutine avR2(vid,bid,cid,cfid,pext,lid,perm,co,cop)
      integer, intent(in) :: vid,bid,cid,cfid,pext,lid,perm
      integer, dimension(0:), intent(in) :: co, cop
      integer scop,i
      vertices(vid)%branchR2(bid)%color_id = cid
      vertices(vid)%branchR2(bid)%colorfac_id = cfid
      vertices(vid)%branchR2(bid)%pext = pext
      vertices(vid)%branchR2(bid)%lorentz_id = lid
      vertices(vid)%branchR2(bid)%perm = perm
      vertices(vid)%branchR2(bid)%coupling_order = co
      scop = size(cop)
      allocate(vertices(vid)%branchR2(bid)%couplings(0:scop-1))
      do i = 0, scop-1
        vertices(vid)%branchR2(bid)%couplings(i) = cop(i)
      end do
    end subroutine avR2

    function get_colourfac_mdl(cfid)
      integer, intent(in) :: cfid
      complex(dp) :: get_colourfac_mdl
      get_colourfac_mdl = colorcoeffs(cfid)
    end function get_colourfac_mdl

    function get_colourfac_form_mdl(cfid)
      integer, intent(in) :: cfid
      character(len=20) :: get_colourfac_form_mdl
      get_colourfac_form_mdl = colorcoeffs_form(cfid)
    end function get_colourfac_form_mdl

  function get_recola_base_mdl(l_id) result(ret_rb)
      integer, intent(in) :: l_id
      integer :: ret_rb
      ret_rb = recola_base(l_id)
    end function get_recola_base_mdl

  subroutine get_vertex_branch_status_mdl(vx,xlp,branch_exists)
    integer, intent(in)  :: vx,xlp
    logical, intent(out) ::branch_exists
    select case (xlp)
    case(TreeBranch:LoopBranch)
      branch_exists = allocated(vertices(vx)%branch)
    case(CTBranch)
      branch_exists = allocated(vertices(vx)%branchCT)
    case(R2Branch)
      branch_exists = allocated(vertices(vx)%branchR2)
    end select
  end subroutine get_vertex_branch_status_mdl

  subroutine get_vertex_colour_branches_mdl(vx,xlp,cfids,nbranches)
    integer, allocatable, intent(out) :: cfids(:)
    integer, intent(out) :: nbranches
    integer, intent(in)  :: vx,xlp
    select case (xlp)
    case (TreeBranch:LoopBranch)
      allocate(cfids(size(vertices(vx)%branch)))
      cfids(:) = vertices(vx)%branch(0:)%color_id
      nbranches = size(vertices(vx)%branch)
    case(CTBranch)
      allocate(cfids(size(vertices(vx)%branchCT)))
      cfids(:) = vertices(vx)%branchCT(0:)%color_id
      nbranches = size(vertices(vx)%branchCT)
    case(R2Branch)
      allocate(cfids(size(vertices(vx)%branchR2)))
      cfids(:) = vertices(vx)%branchR2(0:)%color_id
      nbranches = size(vertices(vx)%branchR2)
    end select
  end subroutine get_vertex_colour_branches_mdl

  subroutine get_vertex_pext_mdl(vx,xlp,br,pext)
    integer, intent(in) :: vx,xlp,br
    integer, intent(out) :: pext
    select case (xlp)
    case (TreeBranch:LoopBranch)
      pext = vertices(vx)%branch(br)%pext
    case(CTBranch)
      pext = vertices(vx)%branchCT(br)%pext
    case(R2Branch)
      pext = vertices(vx)%branchR2(br)%pext
    end select
  end subroutine get_vertex_pext_mdl

  subroutine get_vertex_order_increase_mdl(vx,xlp,br,orderInc)
    integer, intent(in) :: vx,xlp,br
    integer, dimension(:), intent(out) :: orderInc
    select case (xlp)
    case (TreeBranch:LoopBranch)
      orderInc = vertices(vx)%branch(br)%coupling_order
    case(CTBranch)
      orderInc = vertices(vx)%branchCT(br)%coupling_order
    case(R2Branch)
      orderInc = vertices(vx)%branchR2(br)%coupling_order
    end select
  end subroutine get_vertex_order_increase_mdl

  subroutine get_vertex_lorentz_type_mdl(vx,xlp,br,lid)
    integer, intent(in)  :: vx,xlp,br
    integer, intent(out) :: lid
    select case (xlp)
    case (TreeBranch:LoopBranch)
      lid = vertices(vx)%branch(br)%lorentz_id
    case(CTBranch)
      lid = vertices(vx)%branchCT(br)%lorentz_id
    case(R2Branch)
      lid = vertices(vx)%branchR2(br)%lorentz_id
    end select
  end subroutine get_vertex_lorentz_type_mdl

  subroutine get_vertex_perm_mdl(vx,xlp,br,perm)
    integer, intent(in)  :: vx,xlp,br
    integer, intent(out) :: perm
    select case (xlp)
    case (TreeBranch:LoopBranch)
      perm = vertices(vx)%branch(br)%perm
    case(CTBranch)
      perm = vertices(vx)%branchCT(br)%perm
    case(R2Branch)
      perm = vertices(vx)%branchR2(br)%perm
    end select
  end subroutine get_vertex_perm_mdl

  subroutine get_vertex_colour_id_mdl(vx,xlp,br,cid)
    integer, intent(in)  :: vx,xlp,br
    integer, intent(out) :: cid
    select case (xlp)
    case (TreeBranch:LoopBranch)
      cid = vertices(vx)%branch(br)%colorfac_id
    case(CTBranch)
      cid = vertices(vx)%branchCT(br)%colorfac_id
    case(R2Branch)
      cid = vertices(vx)%branchR2(br)%colorfac_id
    end select
  end subroutine get_vertex_colour_id_mdl

  function is_zero_coupling_vertex_mdl(vx,xlp,br) result(zero)
    use class_couplings, only: get_coupling_value_mdl
    use input_mdl, only: zerocut
    integer, intent(in)  :: vx,xlp,br
    logical              :: zero
    real(dp)             :: maxvalue
    integer              :: i

    zero = .false.
    select case (xlp)
    case (TreeBranch:LoopBranch)
      maxvalue = 0d0
      do i = 1,size(vertices(vx)%branch(br)%couplings)
        maxvalue = maxvalue + &
                abs(get_coupling_value_mdl(vertices(vx)%branch(br)%couplings(i-&
                1)))
      end do
      if (maxvalue/zerocut .lt. 100d0) then
        zero = .true.
      end if
    case(CTBranch)
      maxvalue = 0d0
      do i = 1,size(vertices(vx)%branchCT(br)%couplings)
        maxvalue = maxvalue + &
                abs(get_coupling_value_mdl(vertices(vx)%branchCT(br)%couplings(&
                i-1)))
      end do
      if (maxvalue/zerocut .lt. 100d0) then
        zero = .true.
      end if
    case(R2Branch)
      maxvalue = 0d0
      do i = 1,size(vertices(vx)%branchR2(br)%couplings)
        maxvalue = maxvalue + &
                abs(get_coupling_value_mdl(vertices(vx)%branchR2(br)%couplings(&
                i-1)))
      end do
      if (maxvalue/zerocut .lt. 100d0) then
        zero = .true.
      end if
    end select
  end function is_zero_coupling_vertex_mdl

  subroutine get_vertex_ncouplings_mdl(vx,xlp,br,ncouplings)
    integer, intent(in)  :: vx,xlp,br
    integer, intent(out) :: ncouplings
    select case(xlp)
    case(TreeBranch, LoopBranch)
      ncouplings = size(vertices(vx)%branch(br)%couplings)
    case (CTBranch)
      ncouplings = size(vertices(vx)%branchCT(br)%couplings)
    case (R2Branch)
      ncouplings = size(vertices(vx)%branchR2(br)%couplings)
    end select
  end subroutine get_vertex_ncouplings_mdl

  subroutine get_vertex_coupling_ids_mdl(vx,xlp,br,cids)
    integer, intent(in)  :: vx,xlp,br
    integer, intent(out) :: cids(:)
    select case(xlp)
    case(TreeBranch, LoopBranch)
      cids(:) = vertices(vx)%branch(br)%couplings(:)
    case (CTBranch)
      cids(:) = vertices(vx)%branchCT(br)%couplings(:)
    case (R2Branch)
      cids(:) = vertices(vx)%branchR2(br)%couplings(:)
    end select
  end subroutine get_vertex_coupling_ids_mdl

    subroutine createCurrent2(P1, P2, id, check)
      integer, intent(in) :: P1, P2, id
      logical, intent(in) :: check
      integer(kind=8) :: key
      integer :: res,address
      logical :: found
      call createParticleConfig(P1, P2, key)
      if (.not. check) then
        call dict(key, 2, address, found, id)
      else
        call dict(key, 1, address, found, 0)
        res = dict_get_value(address)
        write (*,*) "out=", res, found, address, "shouldbe = ", id
        if (res /= id) then
          stop 9
        end if 
      end if 
    end subroutine createCurrent2

    subroutine createCurrent3(P1, P2, P3, id, check)
      integer, intent(in) :: P1, P2, P3, id
      logical, intent(in) :: check
      integer(kind=8) :: key
      integer :: res,address
      logical :: found
      call createParticleConfig(P1, P2, P3, key)
      if (.not. check) then
        call dict(key, 2, address, found, id)
      else
        call dict(key, 1, address, found, 0)
        res = dict_get_value(address)
        write (*,*) "out=", res, found, address, "shouldbe = ", id
        if (res /= id) then
          stop 9
        end if 
      end if 
    end subroutine createCurrent3

    subroutine createCurrent4(P1, P2, P3, P4, id, check)
      integer, intent(in) :: P1, P2, P3, P4, id
      logical, intent(in) :: check
      integer(kind=8) :: key
      integer :: res,address
      logical :: found
      call createParticleConfig(P1, P2, P3, P4, key)
      if (.not. check) then
        call dict(key, 2, address, found, id)
      else
        call dict(key, 1, address, found, 0)
        res = dict_get_value(address)
        write (*,*) "out=", res, found, address, "shouldbe = ", id
        if (res /= id) then
          stop 9
        end if 
      end if 
    end subroutine createCurrent4

    subroutine createCurrent5(P1, P2, P3, P4, P5, id, check)
      integer, intent(in) :: P1, P2, P3, P4, P5, id
      logical, intent(in) :: check
      integer(kind=8) :: key
      integer :: res,address
      logical :: found
      call createParticleConfig(P1, P2, P3, P4, P5, key)
      if (.not. check) then
        call dict(key, 2, address, found, id)
      else
        call dict(key, 1, address, found, 0)
        res = dict_get_value(address)
        write (*,*) "out=", res, found, address, "shouldbe = ", id
        if (res /= id) then
          stop 9
        end if 
      end if 
    end subroutine createCurrent5

    subroutine createCurrent6(P1, P2, P3, P4, P5, P6, id, check)
      integer, intent(in) :: P1, P2, P3, P4, P5, P6, id
      logical, intent(in) :: check
      integer(kind=8) :: key
      integer :: res,address
      logical :: found
      call createParticleConfig(P1, P2, P3, P4, P5, P6, key)
      if (.not. check) then
        call dict(key, 2, address, found, id)
      else
        call dict(key, 1, address, found, 0)
        res = dict_get_value(address)
        write (*,*) "out=", res, found, address, "shouldbe = ", id
        if (res /= id) then
          stop 9
        end if 
      end if 
    end subroutine createCurrent6

    subroutine createCurrent7(P1, P2, P3, P4, P5, P6, P7, id, check)
      integer, intent(in) :: P1, P2, P3, P4, P5, P6, P7, id
      logical, intent(in) :: check
      integer(kind=8) :: key
      integer :: res,address
      logical :: found
      call createParticleConfig(P1, P2, P3, P4, P5, P6, P7, key)
      if (.not. check) then
        call dict(key, 2, address, found, id)
      else
        call dict(key, 1, address, found, 0)
        res = dict_get_value(address)
        write (*,*) "out=", res, found, address, "shouldbe = ", id
        if (res /= id) then
          stop 9
        end if 
      end if 
    end subroutine createCurrent7

    subroutine createCurrent8(P1, P2, P3, P4, P5, P6, P7, P8, id, check)
      integer, intent(in) :: P1, P2, P3, P4, P5, P6, P7, P8, id
      logical, intent(in) :: check
      integer(kind=8) :: key
      integer :: res,address
      logical :: found
      call createParticleConfig(P1, P2, P3, P4, P5, P6, P7, P8, key)
      if (.not. check) then
        call dict(key, 2, address, found, id)
      else
        call dict(key, 1, address, found, 0)
        res = dict_get_value(address)
        write (*,*) "out=", res, found, address, "shouldbe = ", id
        if (res /= id) then
          stop 9
        end if 
      end if 
    end subroutine createCurrent8

    subroutine init_vertices_mdl()
      use constants_mdl
      use input_mdl, only: nx, error_mdl

      ! check if modelfile is compatible to drivers
      if (model_timestamp .ne. driver_timestamp) then
        call error_mdl("Model corrupted. Driver timestamp mismatch.", &
                      where='init_vertices')
      end if

      vertices_init = .true.
      call fill_couplings_mdl
      call init_CTparameters_mdl(.true.)
      call fill_CTcouplings_mdl
      call dict_init(3347)
      call createCurrents(.false.)

    end subroutine init_vertices_mdl

    subroutine createCurrents(check)
      logical, intent(in) :: check
      call createCurrent(P_GMinus, P_G0, P_A, P_WPlus, 757, check)
      call createCurrent(P_WPlus, P_GPlus, P_GMinus, P_WMinus, 655, check)
      call createCurrent(P_GPlus, P_b, P_tAnti, 1188, check)
      call createCurrent(P_GPlus, P_A, P_Z, P_GMinus, 992, check)
      call createCurrent(P_G0, P_WMinus, P_WPlus, P_G0, 703, check)
      call createCurrent(P_Z, P_Hl, P_GPlus, P_WMinus, 1326, check)
      call createCurrent(P_GPlus, P_Hl, P_GMinus, 355, check)
      call createCurrent(P_Hl, P_WMinus, P_A, P_GPlus, 329, check)
      call createCurrent(P_g, P_g, P_Hl, P_Hl, 1589, check)
      call createCurrent(P_Hh, P_cAnti, P_c, 1098, check)
      call createCurrent(P_Hh, P_Hl, P_Hh, P_Hh, 812, check)
      call createCurrent(P_G0, P_G0, P_G0, P_G0, 637, check)
      call createCurrent(P_ghWm, P_ghWmAnti, P_G0, 200, check)
      call createCurrent(P_GPlus, P_Hh, P_WMinus, P_Z, 1179, check)
      call createCurrent(P_GPlus, P_Hl, P_GMinus, P_Hl, 852, check)
      call createCurrent(P_GPlus, P_A, P_G0, P_WMinus, 891, check)
      call createCurrent(P_WMinus, P_G0, P_G0, P_WPlus, 1192, check)
      call createCurrent(P_Hl, P_Z, P_Z, 738, check)
      call createCurrent(P_Z, P_WMinus, P_WPlus, 525, check)
      call createCurrent(P_Hl, P_G0, P_G0, P_Hh, 1024, check)
      call createCurrent(P_sAnti, P_g, P_s, 239, check)
      call createCurrent(P_ghWp, P_Hh, P_ghWpAnti, 667, check)
      call createCurrent(P_Z, P_Hh, P_A, P_Hh, 1384, check)
      call createCurrent(P_A, P_ePlus, P_eMinus, 701, check)
      call createCurrent(P_g, P_Hh, P_g, P_Hl, 1666, check)
      call createCurrent(P_GMinus, P_Hl, P_GPlus, P_Hh, 1118, check)
      call createCurrent(P_G0, P_GPlus, P_WMinus, P_A, 1077, check)
      call createCurrent(P_tauMinus, P_tauPlus, 1437, check)
      call createCurrent(P_nu_eAnti, P_eMinus, P_GPlus, 744, check)
      call createCurrent(P_GPlus, P_Hl, P_Z, P_WMinus, 1129, check)
      call createCurrent(P_Z, P_tauPlus, P_tauMinus, 472, check)
      call createCurrent(P_WMinus, P_dAnti, P_u, 795, check)
      call createCurrent(P_muPlus, P_muMinus, P_Hh, 732, check)
      call createCurrent(P_G0, P_g, P_G0, P_g, 1557, check)
      call createCurrent(P_WMinus, P_ghWmAnti, P_ghA, 362, check)
      call createCurrent(P_Z, P_WPlus, P_A, P_WMinus, 1105, check)
      call createCurrent(P_A, P_Hl, P_A, 1632, check)
      call createCurrent(P_Z, P_Hh, P_WPlus, P_GMinus, 224, check)
      call createCurrent(P_tauMinus, P_nu_tauAnti, P_GPlus, 837, check)
      call createCurrent(P_GMinus, P_Hh, P_WPlus, 1177, check)
      call createCurrent(P_nu_muAnti, P_nu_mu, P_A, 1477, check)
      call createCurrent(P_WPlus, P_GMinus, P_A, P_Hl, 346, check)
      call createCurrent(P_GPlus, P_Z, P_Hh, P_WMinus, 44, check)
      call createCurrent(P_ghWm, P_Hl, P_ghWmAnti, 1293, check)
      call createCurrent(P_A, P_Hl, P_A, P_Hl, 1657, check)
      call createCurrent(P_Z, P_WPlus, P_Z, P_WMinus, 391, check)
      call createCurrent(P_A, P_Hl, P_Hh, P_Z, 1466, check)
      call createCurrent(P_GMinus, P_GPlus, P_Hl, P_Hl, 558, check)
      call createCurrent(P_A, P_ghWm, P_ghWmAnti, 114, check)
      call createCurrent(P_dAnti, P_d, P_Hl, 381, check)
      call createCurrent(P_Z, P_GPlus, P_WMinus, P_Hh, 611, check)
      call createCurrent(P_bAnti, P_b, P_g, 586, check)
      call createCurrent(P_cAnti, P_Z, P_c, 593, check)
      call createCurrent(P_GPlus, P_Hh, P_Hl, P_GMinus, 1253, check)
      call createCurrent(P_eMinus, P_WPlus, P_nu_eAnti, 1006, check)
      call createCurrent(P_uAnti, P_u, P_Hl, 1154, check)
      call createCurrent(P_GPlus, P_GMinus, P_WPlus, P_WMinus, 181, check)
      call createCurrent(P_Z, P_ePlus, P_eMinus, 356, check)
      call createCurrent(P_A, P_tauPlus, P_tauMinus, 351, check)
      call createCurrent(P_A, P_Hh, P_A, 1556, check)
      call createCurrent(P_Z, P_WPlus, P_WMinus, P_Z, 612, check)
      call createCurrent(P_t, P_Z, P_tAnti, 579, check)
      call createCurrent(P_G0, P_dAnti, P_d, 972, check)
      call createCurrent(P_ghZAnti, P_GMinus, P_ghWp, 158, check)
      call createCurrent(P_GPlus, P_Hl, P_A, P_WMinus, 727, check)
      call createCurrent(P_Hl, P_GPlus, P_A, P_WMinus, 214, check)
      call createCurrent(P_s, P_Z, P_sAnti, 678, check)
      call createCurrent(P_GMinus, P_A, P_GPlus, P_Z, 256, check)
      call createCurrent(P_Hl, P_muMinus, P_muPlus, 1363, check)
      call createCurrent(P_nu_e, P_WMinus, P_ePlus, 10, check)
      call createCurrent(P_eMinus, P_Hh, P_ePlus, 784, check)
      call createCurrent(P_GMinus, P_WPlus, P_G0, P_Z, 437, check)
      call createCurrent(P_t, P_Hl, P_tAnti, 918, check)
      call createCurrent(P_g, P_g, P_Hh, P_Hh, 1672, check)
      call createCurrent(P_A, P_muPlus, P_muMinus, 371, check)
      call createCurrent(P_WMinus, P_GMinus, P_GPlus, P_WPlus, 1167, check)
      call createCurrent(P_G0, P_uAnti, P_u, 1284, check)
      call createCurrent(P_Hh, P_Hl, P_Hh, P_Hl, 687, check)
      call createCurrent(P_Hh, P_Hh, P_Hl, 575, check)
      call createCurrent(P_G0, P_c, P_cAnti, 980, check)
      call createCurrent(P_GPlus, P_Hh, P_WMinus, P_A, 1290, check)
      call createCurrent(P_GMinus, P_WPlus, P_G0, 453, check)
      call createCurrent(P_nu_mu, P_nu_muAnti, P_Z, 1283, check)
      call createCurrent(P_GPlus, P_A, P_WMinus, P_G0, 488, check)
      call createCurrent(P_Hh, P_Hl, P_Hl, P_Hl, 366, check)
      call createCurrent(P_GPlus, P_Hh, P_A, P_WMinus, 528, check)
      call createCurrent(P_nu_tau, P_nu_tauAnti, P_A, 1445, check)
      call createCurrent(P_Hh, P_Hl, P_Hl, 20, check)
      call createCurrent(P_Hh, P_Hh, P_Hl, P_Hh, 1093, check)
      call createCurrent(P_WMinus, P_g, P_WPlus, P_g, 1596, check)
      call createCurrent(P_Z, P_WMinus, P_GPlus, P_Hh, 1316, check)
      call createCurrent(P_Hl, P_G0, P_Z, 190, check)
      call createCurrent(P_GMinus, P_WPlus, P_Z, P_Hh, 816, check)
      call createCurrent(P_A, P_G0, P_Hh, 1492, check)
      call createCurrent(P_muMinus, P_nu_muAnti, P_WPlus, 451, check)
      call createCurrent(P_g, P_A, P_g, P_Z, 1599, check)
      call createCurrent(P_u, P_uAnti, P_Hh, 1159, check)
      call createCurrent(P_Hh, P_ghWp, P_ghWpAnti, 394, check)
      call createCurrent(P_nu_mu, P_nu_muAnti, P_A, 1485, check)
      call createCurrent(P_Z, P_WMinus, P_GPlus, P_G0, 536, check)
      call createCurrent(P_Hl, P_WPlus, P_GMinus, 246, check)
      call createCurrent(P_dAnti, P_d, P_A, 358, check)
      call createCurrent(P_Z, P_uAnti, P_u, 758, check)
      call createCurrent(P_GPlus, P_GMinus, P_A, P_Z, 486, check)
      call createCurrent(P_tauMinus, P_tauPlus, P_Hh, 1380, check)
      call createCurrent(P_Z, P_WMinus, P_G0, P_GPlus, 763, check)
      call createCurrent(P_GPlus, P_nu_muAnti, P_muMinus, 128, check)
      call createCurrent(P_g, P_cAnti, P_c, 914, check)
      call createCurrent(P_Hl, P_A, P_WPlus, P_GMinus, 1059, check)
      call createCurrent(P_dAnti, P_g, P_d, 912, check)
      call createCurrent(P_Hh, P_Hl, P_GPlus, P_GMinus, 1038, check)
      call createCurrent(P_c, P_cAnti, P_A, 560, check)
      call createCurrent(P_G0, P_A, P_Hh, 1512, check)
      call createCurrent(P_WPlus, P_Hl, P_Hl, P_WMinus, 498, check)
      call createCurrent(P_WPlus, P_g, P_WMinus, P_g, 1610, check)
      call createCurrent(P_tAnti, P_t, P_A, 1035, check)
      call createCurrent(P_Hl, P_Z, P_A, P_Hl, 1448, check)
      call createCurrent(P_WMinus, P_WPlus, P_Hl, 460, check)
      call createCurrent(P_ghZAnti, P_ghWm, P_GPlus, 606, check)
      call createCurrent(P_WMinus, P_Hl, P_WPlus, P_Hl, 946, check)
      call createCurrent(P_c, P_sAnti, P_WMinus, 565, check)
      call createCurrent(P_Hh, P_A, P_WMinus, P_GPlus, 573, check)
      call createCurrent(P_A, P_d, P_dAnti, 566, check)
      call createCurrent(P_GPlus, P_tauMinus, P_nu_tauAnti, 913, check)
      call createCurrent(P_ePlus, P_Hh, P_eMinus, 986, check)
      call createCurrent(P_WPlus, P_ghZ, P_ghWpAnti, 695, check)
      call createCurrent(P_muPlus, P_nu_mu, P_WMinus, 462, check)
      call createCurrent(P_A, P_Hl, P_Z, P_Hh, 1450, check)
      call createCurrent(P_Hl, P_Z, P_G0, 834, check)
      call createCurrent(P_Hl, P_GPlus, P_WMinus, P_Z, 1367, check)
      call createCurrent(P_Z, P_G0, P_WMinus, P_GPlus, 861, check)
      call createCurrent(P_sAnti, P_A, P_s, 1162, check)
      call createCurrent(P_Z, P_GPlus, P_GMinus, P_A, 534, check)
      call createCurrent(P_WMinus, P_GPlus, P_WPlus, P_GMinus, 342, check)
      call createCurrent(P_Hh, P_Hl, P_WPlus, P_WMinus, 195, check)
      call createCurrent(P_WPlus, P_Hh, P_A, P_GMinus, 958, check)
      call createCurrent(P_GPlus, P_Hh, P_GMinus, 842, check)
      call createCurrent(P_Hh, P_Hl, 1474, check)
      call createCurrent(P_Hh, P_A, P_A, P_Hh, 1597, check)
      call createCurrent(P_GMinus, P_WPlus, P_A, P_Hh, 36, check)
      call createCurrent(P_A, P_nu_muAnti, P_nu_mu, 1497, check)
      call createCurrent(P_Z, P_A, P_Hl, P_Hh, 1443, check)
      call createCurrent(P_G0, P_WMinus, P_GPlus, P_A, 378, check)
      call createCurrent(P_WMinus, P_A, P_GPlus, P_G0, 618, check)
      call createCurrent(P_uAnti, P_u, P_g, 862, check)
      call createCurrent(P_Z, P_A, P_Hl, 1444, check)
      call createCurrent(P_ghWp, P_A, P_ghWpAnti, 890, check)
      call createCurrent(P_u, P_uAnti, 1435, check)
      call createCurrent(P_Z, P_Hh, P_GPlus, P_WMinus, 1184, check)
      call createCurrent(P_ghWpAnti, P_Hh, P_ghWp, 1214, check)
      call createCurrent(P_G0, P_Hh, P_G0, 1008, check)
      call createCurrent(P_ghZ, P_Hl, P_ghZAnti, 1173, check)
      call createCurrent(P_GPlus, P_Hl, P_Hl, P_GMinus, 415, check)
      call createCurrent(P_tAnti, P_t, P_Z, 1307, check)
      call createCurrent(P_WPlus, P_GMinus, P_WMinus, P_GPlus, 1256, check)
      call createCurrent(P_GMinus, P_A, P_Hl, P_WPlus, 1212, check)
      call createCurrent(P_Hl, P_A, P_Hh, P_Z, 1401, check)
      call createCurrent(P_GPlus, P_A, P_WMinus, P_Hl, 783, check)
      call createCurrent(P_WMinus, P_G0, P_Z, P_GPlus, 218, check)
      call createCurrent(P_sAnti, P_s, P_Z, 530, check)
      call createCurrent(P_Z, P_Hl, P_Z, P_Hh, 1155, check)
      call createCurrent(P_Hh, P_ghZAnti, P_ghZ, 700, check)
      call createCurrent(P_A, P_Z, P_WPlus, P_WMinus, 397, check)
      call createCurrent(P_Hh, P_Hh, P_WPlus, P_WMinus, 295, check)
      call createCurrent(P_G0, P_Z, P_WPlus, P_GMinus, 993, check)
      call createCurrent(P_WMinus, P_Hl, P_Hh, P_WPlus, 561, check)
      call createCurrent(P_Z, P_Z, P_GMinus, P_GPlus, 384, check)
      call createCurrent(P_cAnti, P_c, 1496, check)
      call createCurrent(P_c, P_cAnti, P_G0, 1191, check)
      call createCurrent(P_GPlus, P_eMinus, P_nu_eAnti, 814, check)
      call createCurrent(P_ghWpAnti, P_ghWp, P_Z, 902, check)
      call createCurrent(P_G0, P_tAnti, P_t, 401, check)
      call createCurrent(P_Z, P_G0, P_Z, P_G0, 955, check)
      call createCurrent(P_s, P_GPlus, P_cAnti, 570, check)
      call createCurrent(P_WPlus, P_GMinus, P_G0, 237, check)
      call createCurrent(P_GPlus, P_WMinus, P_GMinus, P_WPlus, 673, check)
      call createCurrent(P_dAnti, P_d, P_g, 938, check)
      call createCurrent(P_ghWmAnti, P_ghWm, P_Hh, 367, check)
      call createCurrent(P_WMinus, P_G0, P_A, P_GPlus, 959, check)
      call createCurrent(P_Z, P_Hl, P_Z, 1250, check)
      call createCurrent(P_c, P_cAnti, 1397, check)
      call createCurrent(P_Hl, P_A, P_A, P_Hh, 1584, check)
      call createCurrent(P_ePlus, P_eMinus, P_Hh, 981, check)
      call createCurrent(P_Hh, P_GPlus, P_WMinus, P_A, 564, check)
      call createCurrent(P_Z, P_GPlus, P_Hl, P_WMinus, 813, check)
      call createCurrent(P_WMinus, P_GPlus, P_Z, P_Hh, 919, check)
      call createCurrent(P_GPlus, P_s, P_cAnti, 733, check)
      call createCurrent(P_uAnti, P_GPlus, P_d, 880, check)
      call createCurrent(P_A, P_WMinus, P_Hl, P_GPlus, 57, check)
      call createCurrent(P_s, P_sAnti, P_g, 6, check)
      call createCurrent(P_uAnti, P_Z, P_u, 681, check)
      call createCurrent(P_GMinus, P_Hl, P_Z, P_WPlus, 991, check)
      call createCurrent(P_ghWpAnti, P_ghA, P_WPlus, 1115, check)
      call createCurrent(P_Hh, P_tAnti, P_t, 1358, check)
      call createCurrent(P_A, P_Hh, P_A, P_Hh, 1613, check)
      call createCurrent(P_d, P_dAnti, 1484, check)
      call createCurrent(P_t, P_Hh, P_tAnti, 669, check)
      call createCurrent(P_nu_e, P_ePlus, P_WMinus, 1357, check)
      call createCurrent(P_Z, P_nu_e, P_nu_eAnti, 574, check)
      call createCurrent(P_sAnti, P_s, P_Hl, 1332, check)
      call createCurrent(P_WMinus, P_WPlus, P_Hl, P_Hl, 749, check)
      call createCurrent(P_A, P_A, P_Hh, P_Hl, 1655, check)
      call createCurrent(P_G0, P_d, P_dAnti, 74, check)
      call createCurrent(P_bAnti, P_G0, P_b, 283, check)
      call createCurrent(P_GPlus, P_Hl, P_Hh, P_GMinus, 146, check)
      call createCurrent(P_GPlus, P_G0, P_GMinus, P_G0, 141, check)
      call createCurrent(P_u, P_uAnti, P_A, 53, check)
      call createCurrent(P_GMinus, P_A, P_Hh, P_WPlus, 1182, check)
      call createCurrent(P_A, P_Hh, P_G0, 1516, check)
      call createCurrent(P_bAnti, P_Z, P_b, 220, check)
      call createCurrent(P_A, P_Z, P_Hl, P_Hl, 1457, check)
      call createCurrent(P_Z, P_GMinus, P_Hh, P_WPlus, 1245, check)
      call createCurrent(P_Hh, P_Hh, P_G0, P_G0, 1236, check)
      call createCurrent(P_G0, P_tauPlus, P_tauMinus, 513, check)
      call createCurrent(P_d, P_dAnti, P_A, 464, check)
      call createCurrent(P_Z, P_GPlus, P_Z, P_GMinus, 110, check)
      call createCurrent(P_WMinus, P_Z, P_Hl, P_GPlus, 1381, check)
      call createCurrent(P_Hl, P_A, P_G0, 1391, check)
      call createCurrent(P_WPlus, P_WMinus, 1467, check)
      call createCurrent(P_G0, P_Z, P_WMinus, P_GPlus, 755, check)
      call createCurrent(P_nu_tauAnti, P_A, P_nu_tau, 1406, check)
      call createCurrent(P_eMinus, P_Hl, P_ePlus, 1282, check)
      call createCurrent(P_Z, P_nu_tauAnti, P_nu_tau, 1018, check)
      call createCurrent(P_muPlus, P_Hh, P_muMinus, 741, check)
      call createCurrent(P_Hl, P_t, P_tAnti, 906, check)
      call createCurrent(P_A, P_A, P_GMinus, P_GPlus, 1225, check)
      call createCurrent(P_Hh, P_g, P_Hh, P_g, 1535, check)
      call createCurrent(P_muPlus, P_muMinus, P_Hl, 771, check)
      call createCurrent(P_muPlus, P_A, P_muMinus, 455, check)
      call createCurrent(P_WMinus, P_A, P_G0, P_GPlus, 737, check)
      call createCurrent(P_G0, P_GMinus, P_WPlus, P_A, 169, check)
      call createCurrent(P_GPlus, P_A, P_A, P_GMinus, 947, check)
      call createCurrent(P_eMinus, P_GPlus, P_nu_eAnti, 300, check)
      call createCurrent(P_WPlus, P_Z, P_A, P_WMinus, 769, check)
      call createCurrent(P_ghWp, P_Z, P_ghWpAnti, 522, check)
      call createCurrent(P_Hl, P_Hl, P_Hh, P_Hl, 142, check)
      call createCurrent(P_Hh, P_Z, P_A, P_Hl, 1459, check)
      call createCurrent(P_s, P_WPlus, P_cAnti, 403, check)
      call createCurrent(P_GPlus, P_Z, P_WMinus, P_Hl, 750, check)
      call createCurrent(P_dAnti, P_WMinus, P_u, 1286, check)
      call createCurrent(P_Hh, P_g, P_g, P_Hh, 1590, check)
      call createCurrent(P_Hl, P_WPlus, P_GMinus, P_Z, 1174, check)
      call createCurrent(P_g, P_WMinus, P_g, P_WPlus, 1665, check)
      call createCurrent(P_dAnti, P_d, P_Hh, 341, check)
      call createCurrent(P_Z, P_Hh, P_Z, 404, check)
      call createCurrent(P_Z, P_Z, P_Z, P_A, 1641, check)
      call createCurrent(P_ghWpAnti, P_A, P_ghWp, 666, check)
      call createCurrent(P_G0, P_GMinus, P_Z, P_WPlus, 1324, check)
      call createCurrent(P_uAnti, P_u, P_Hh, 1315, check)
      call createCurrent(P_Hh, P_Z, P_GPlus, P_WMinus, 1318, check)
      call createCurrent(P_g, P_Hl, P_Hl, P_g, 1585, check)
      call createCurrent(P_GPlus, P_g, P_GMinus, P_g, 1649, check)
      call createCurrent(P_GPlus, P_Hh, P_WMinus, 1298, check)
      call createCurrent(P_Hh, P_A, P_G0, 1400, check)
      call createCurrent(P_A, P_Z, P_WMinus, P_WPlus, 1069, check)
      call createCurrent(P_G0, P_Hl, P_G0, P_Hl, 1350, check)
      call createCurrent(P_A, P_s, P_sAnti, 163, check)
      call createCurrent(P_WMinus, P_A, P_WPlus, P_Z, 974, check)
      call createCurrent(P_Hl, P_Hh, P_Z, P_Z, 77, check)
      call createCurrent(P_A, P_WMinus, P_Z, P_WPlus, 205, check)
      call createCurrent(P_d, P_g, P_dAnti, 864, check)
      call createCurrent(P_g, P_t, P_tAnti, 796, check)
      call createCurrent(P_G0, P_Z, P_G0, P_Z, 1051, check)
      call createCurrent(P_t, P_tAnti, 1442, check)
      call createCurrent(P_A, P_Z, P_Z, P_A, 1668, check)
      call createCurrent(P_GMinus, P_Hl, P_WPlus, 645, check)
      call createCurrent(P_ghWpAnti, P_WPlus, P_ghZ, 5, check)
      call createCurrent(P_GMinus, P_Hh, P_Hh, P_GPlus, 280, check)
      call createCurrent(P_nu_mu, P_nu_muAnti, 1439, check)
      call createCurrent(P_GMinus, P_GMinus, P_GPlus, P_GPlus, 1121, check)
      call createCurrent(P_GMinus, P_A, P_WPlus, 196, check)
      call createCurrent(P_WPlus, P_GMinus, P_Hh, P_Z, 197, check)
      call createCurrent(P_A, P_WMinus, P_G0, P_GPlus, 1371, check)
      call createCurrent(P_A, P_G0, P_WPlus, P_GMinus, 492, check)
      call createCurrent(P_u, P_uAnti, P_Z, 900, check)
      call createCurrent(P_WMinus, P_Hh, P_A, P_GPlus, 1353, check)
      call createCurrent(P_nu_eAnti, P_nu_e, P_Z, 519, check)
      call createCurrent(P_t, P_bAnti, P_WMinus, 711, check)
      call createCurrent(P_Hh, P_c, P_cAnti, 350, check)
      call createCurrent(P_Hl, P_G0, P_G0, P_Hl, 164, check)
      call createCurrent(P_Hh, P_Hl, P_g, P_g, 1661, check)
      call createCurrent(P_g, P_b, P_bAnti, 951, check)
      call createCurrent(P_A, P_b, P_bAnti, 832, check)
      call createCurrent(P_Hl, P_WMinus, P_WPlus, P_Hl, 167, check)
      call createCurrent(P_ePlus, P_eMinus, P_G0, 768, check)
      call createCurrent(P_Hh, P_Hl, P_Hh, 55, check)
      call createCurrent(P_G0, P_G0, P_Z, P_A, 1494, check)
      call createCurrent(P_g, P_g, P_A, P_A, 1575, check)
      call createCurrent(P_g, P_Z, P_Z, P_g, 1538, check)
      call createCurrent(P_GPlus, P_WMinus, P_A, P_G0, 503, check)
      call createCurrent(P_GMinus, P_nu_tau, P_tauPlus, 1374, check)
      call createCurrent(P_g, P_Hh, P_g, P_Hh, 1544, check)
      call createCurrent(P_A, P_Hh, P_Z, P_Hl, 1424, check)
      call createCurrent(P_A, P_WPlus, P_G0, P_GMinus, 1066, check)
      call createCurrent(P_tauMinus, P_tauPlus, P_Hl, 419, check)
      call createCurrent(P_A, P_GMinus, P_Hh, P_WPlus, 896, check)
      call createCurrent(P_WPlus, P_WMinus, P_WMinus, P_WPlus, 157, check)
      call createCurrent(P_Hl, P_GPlus, P_Hh, P_GMinus, 885, check)
      call createCurrent(P_g, P_GPlus, P_GMinus, P_g, 1603, check)
      call createCurrent(P_WMinus, P_WPlus, P_GPlus, P_GMinus, 599, check)
      call createCurrent(P_G0, P_A, P_G0, P_Z, 1446, check)
      call createCurrent(P_sAnti, P_s, P_G0, 922, check)
      call createCurrent(P_WPlus, P_GMinus, P_A, P_Hh, 1281, check)
      call createCurrent(P_b, P_Hl, P_bAnti, 270, check)
      call createCurrent(P_A, P_Hl, P_A, P_Hh, 1548, check)
      call createCurrent(P_u, P_G0, P_uAnti, 284, check)
      call createCurrent(P_Z, P_Hh, P_Hh, P_A, 1476, check)
      call createCurrent(P_GMinus, P_GPlus, P_Hl, P_Hh, 1030, check)
      call createCurrent(P_A, P_G0, P_G0, P_Z, 1509, check)
      call createCurrent(P_G0, P_sAnti, P_s, 916, check)
      call createCurrent(P_WPlus, P_A, P_Hh, P_GMinus, 720, check)
      call createCurrent(P_Z, P_Hl, P_WPlus, P_GMinus, 863, check)
      call createCurrent(P_ghWmAnti, P_G0, P_ghWm, 998, check)
      call createCurrent(P_WPlus, P_A, P_WMinus, 1134, check)
      call createCurrent(P_Hh, P_A, P_Hh, P_Z, 1390, check)
      call createCurrent(P_eMinus, P_ePlus, P_A, 330, check)
      call createCurrent(P_Hh, P_GPlus, P_WMinus, 908, check)
      call createCurrent(P_GMinus, P_WPlus, P_A, P_G0, 42, check)
      call createCurrent(P_GPlus, P_GMinus, P_g, P_g, 1549, check)
      call createCurrent(P_A, P_Hl, P_Hh, P_A, 1612, check)
      call createCurrent(P_d, P_GPlus, P_uAnti, 18, check)
      call createCurrent(P_Z, P_GMinus, P_Z, P_GPlus, 1305, check)
      call createCurrent(P_GMinus, P_GPlus, P_Z, 1074, check)
      call createCurrent(P_WPlus, P_A, P_GMinus, 1109, check)
      call createCurrent(P_WMinus, P_WPlus, P_WMinus, P_WPlus, 1378, check)
      call createCurrent(P_Hh, P_Hh, P_GPlus, P_GMinus, 787, check)
      call createCurrent(P_GPlus, P_WMinus, P_Hh, P_Z, 1344, check)
      call createCurrent(P_GPlus, P_G0, P_WMinus, P_Z, 1036, check)
      call createCurrent(P_Hh, P_GMinus, P_GPlus, P_Hh, 1216, check)
      call createCurrent(P_ghWm, P_ghZAnti, P_WPlus, 942, check)
      call createCurrent(P_ghZ, P_ghWmAnti, P_GMinus, 1023, check)
      call createCurrent(P_Hh, P_uAnti, P_u, 1189, check)
      call createCurrent(P_Hl, P_Hh, P_g, P_g, 1588, check)
      call createCurrent(P_Hh, P_Hh, P_A, P_A, 1653, check)
      call createCurrent(P_Z, P_A, 1508, check)
      call createCurrent(P_s, P_Hl, P_sAnti, 1300, check)
      call createCurrent(P_Z, P_eMinus, P_ePlus, 1085, check)
      call createCurrent(P_g, P_g, P_g, P_Z, 1633, check)
      call createCurrent(P_WMinus, P_Hh, P_WPlus, P_Hh, 1048, check)
      call createCurrent(P_ghWm, P_A, P_ghWmAnti, 137, check)
      call createCurrent(P_G0, P_GPlus, P_WMinus, P_Z, 594, check)
      call createCurrent(P_WMinus, P_Hh, P_Hh, P_WPlus, 705, check)
      call createCurrent(P_Z, P_WPlus, P_G0, P_GMinus, 1025, check)
      call createCurrent(P_muPlus, P_GMinus, P_nu_mu, 895, check)
      call createCurrent(P_ghZAnti, P_ghWp, P_GMinus, 929, check)
      call createCurrent(P_Hh, P_WPlus, P_A, P_GMinus, 985, check)
      call createCurrent(P_Hh, P_Hl, P_Hl, P_Hh, 1296, check)
      call createCurrent(P_tauMinus, P_tauPlus, P_G0, 140, check)
      call createCurrent(P_Hh, P_Hh, P_Hl, P_Hl, 178, check)
      call createCurrent(P_Z, P_WMinus, P_GPlus, P_Hl, 149, check)
      call createCurrent(P_GMinus, P_WPlus, P_A, 104, check)
      call createCurrent(P_GMinus, P_A, P_G0, P_WPlus, 843, check)
      call createCurrent(P_GPlus, P_Z, P_WMinus, 608, check)
      call createCurrent(P_G0, P_Z, P_Hl, 1060, check)
      call createCurrent(P_c, P_Z, P_cAnti, 3, check)
      call createCurrent(P_A, P_Hl, P_Hl, P_A, 1660, check)
      call createCurrent(P_G0, P_GMinus, P_WPlus, P_Z, 884, check)
      call createCurrent(P_tauPlus, P_tauMinus, P_Hl, 597, check)
      call createCurrent(P_g, P_g, 1488, check)
      call createCurrent(P_ghWpAnti, P_ghWp, P_G0, 1166, check)
      call createCurrent(P_Hl, P_GPlus, P_Hl, P_GMinus, 480, check)
      call createCurrent(P_WMinus, P_ghZ, P_ghWmAnti, 1092, check)
      call createCurrent(P_WPlus, P_nu_eAnti, P_eMinus, 1306, check)
      call createCurrent(P_WPlus, P_A, P_G0, P_GMinus, 723, check)
      call createCurrent(P_Hl, P_A, P_WMinus, P_GPlus, 714, check)
      call createCurrent(P_Hh, P_GPlus, P_GMinus, P_Hh, 1168, check)
      call createCurrent(P_Hh, P_GMinus, P_WPlus, 975, check)
      call createCurrent(P_WPlus, P_ghA, P_ghWpAnti, 664, check)
      call createCurrent(P_WMinus, P_WPlus, P_A, P_A, 953, check)
      call createCurrent(P_c, P_cAnti, P_Hh, 111, check)
      call createCurrent(P_G0, P_G0, P_Hl, P_Hl, 432, check)
      call createCurrent(P_u, P_uAnti, P_g, 1273, check)
      call createCurrent(P_A, P_Hl, P_GMinus, P_WPlus, 729, check)
      call createCurrent(P_ghWm, P_Hh, P_ghWmAnti, 724, check)
      call createCurrent(P_GPlus, P_ghWpAnti, P_ghA, 450, check)
      call createCurrent(P_ePlus, P_nu_e, P_GMinus, 444, check)
      call createCurrent(P_Hl, P_Hh, P_A, P_A, 1587, check)
      call createCurrent(P_Hh, P_WMinus, P_WPlus, 767, check)
      call createCurrent(P_WPlus, P_A, P_Hl, P_GMinus, 1145, check)
      call createCurrent(P_Hl, P_Z, P_A, P_Hh, 1504, check)
      call createCurrent(P_A, P_G0, P_WMinus, P_GPlus, 1372, check)
      call createCurrent(P_WPlus, P_GMinus, 1440, check)
      call createCurrent(P_u, P_g, P_uAnti, 409, check)
      call createCurrent(P_GPlus, P_G0, P_Z, P_WMinus, 285, check)
      call createCurrent(P_A, P_WPlus, P_Hh, P_GMinus, 294, check)
      call createCurrent(P_Hh, P_g, P_g, 1630, check)
      call createCurrent(P_WMinus, P_Hl, P_WPlus, P_Hh, 1009, check)
      call createCurrent(P_nu_tauAnti, P_GPlus, P_tauMinus, 348, check)
      call createCurrent(P_A, P_WPlus, P_Z, P_WMinus, 457, check)
      call createCurrent(P_Hl, P_G0, P_G0, 433, check)
      call createCurrent(P_ePlus, P_eMinus, P_A, 653, check)
      call createCurrent(P_Z, P_Hl, P_A, 1453, check)
      call createCurrent(P_Hl, P_GMinus, P_GPlus, P_Hl, 375, check)
      call createCurrent(P_WPlus, P_GMinus, P_Hl, 773, check)
      call createCurrent(P_ghWp, P_WMinus, P_ghAAnti, 33, check)
      call createCurrent(P_muMinus, P_nu_muAnti, P_GPlus, 206, check)
      call createCurrent(P_WPlus, P_G0, P_GMinus, 1198, check)
      call createCurrent(P_WPlus, P_GMinus, P_G0, P_Z, 835, check)
      call createCurrent(P_t, P_tAnti, P_A, 1047, check)
      call createCurrent(P_GPlus, P_A, P_Hl, P_WMinus, 641, check)
      call createCurrent(P_G0, P_Hh, P_Hh, P_G0, 1356, check)
      call createCurrent(P_WMinus, P_Z, P_GPlus, P_G0, 269, check)
      call createCurrent(P_Hh, P_WMinus, P_A, P_GPlus, 873, check)
      call createCurrent(P_GMinus, P_WPlus, P_A, P_Hl, 508, check)
      call createCurrent(P_WMinus, P_GPlus, P_A, P_Hh, 495, check)
      call createCurrent(P_GPlus, P_A, P_GMinus, P_A, 668, check)
      call createCurrent(P_Z, P_G0, P_G0, P_A, 1407, check)
      call createCurrent(P_sAnti, P_s, P_Hh, 1295, check)
      call createCurrent(P_Z, P_A, P_Hl, P_Hl, 1426, check)
      call createCurrent(P_g, P_Z, P_g, P_Z, 1619, check)
      call createCurrent(P_GPlus, P_Z, P_Z, P_GMinus, 996, check)
      call createCurrent(P_t, P_tAnti, P_G0, 1055, check)
      call createCurrent(P_Hl, P_Hl, P_Z, P_Z, 1090, check)
      call createCurrent(P_WMinus, P_WPlus, P_Z, 12, check)
      call createCurrent(P_d, P_WPlus, P_uAnti, 365, check)
      call createCurrent(P_dAnti, P_u, P_GMinus, 1201, check)
      call createCurrent(P_A, P_Hh, P_Z, 1464, check)
      call createCurrent(P_Hh, P_WPlus, P_Z, P_GMinus, 658, check)
      call createCurrent(P_Hl, P_cAnti, P_c, 1379, check)
      call createCurrent(P_muMinus, P_Hh, P_muPlus, 1340, check)
      call createCurrent(P_Z, P_Hl, P_WMinus, P_GPlus, 789, check)
      call createCurrent(P_Hh, P_Hh, P_GMinus, P_GPlus, 1000, check)
      call createCurrent(P_GPlus, P_G0, P_A, P_WMinus, 117, check)
      call createCurrent(P_G0, P_WMinus, P_G0, P_WPlus, 888, check)
      call createCurrent(P_Hl, P_WMinus, P_WPlus, 1321, check)
      call createCurrent(P_WMinus, P_nu_mu, P_muPlus, 726, check)
      call createCurrent(P_WPlus, P_Z, P_G0, P_GMinus, 1176, check)
      call createCurrent(P_WMinus, P_G0, P_GPlus, 91, check)
      call createCurrent(P_G0, P_eMinus, P_ePlus, 1239, check)
      call createCurrent(P_GPlus, P_A, P_WMinus, P_Hh, 315, check)
      call createCurrent(P_WPlus, P_GMinus, P_A, 874, check)
      call createCurrent(P_WMinus, P_WPlus, P_Z, P_Z, 675, check)
      call createCurrent(P_u, P_dAnti, P_WMinus, 1042, check)
      call createCurrent(P_tAnti, P_GPlus, P_b, 920, check)
      call createCurrent(P_G0, P_Hl, P_G0, 646, check)
      call createCurrent(P_Hh, P_u, P_uAnti, 442, check)
      call createCurrent(P_Z, P_Z, P_g, P_g, 1616, check)
      call createCurrent(P_s, P_A, P_sAnti, 1123, check)
      call createCurrent(P_A, P_WPlus, P_GMinus, P_Hl, 857, check)
      call createCurrent(P_A, P_Hh, P_Hh, P_A, 1646, check)
      call createCurrent(P_Z, P_A, P_A, P_A, 1634, check)
      call createCurrent(P_G0, P_WMinus, P_Z, P_GPlus, 147, check)
      call createCurrent(P_Hl, P_A, P_Z, 1501, check)
      call createCurrent(P_muPlus, P_muMinus, P_G0, 373, check)
      call createCurrent(P_A, P_WPlus, P_Hl, P_GMinus, 4, check)
      call createCurrent(P_A, P_Z, P_A, P_Z, 1592, check)
      call createCurrent(P_WPlus, P_d, P_uAnti, 1153, check)
      call createCurrent(P_Z, P_A, P_G0, P_G0, 1447, check)
      call createCurrent(P_GMinus, P_bAnti, P_t, 129, check)
      call createCurrent(P_tauPlus, P_Hl, P_tauMinus, 1132, check)
      call createCurrent(P_Hh, P_GPlus, P_WMinus, P_Z, 547, check)
      call createCurrent(P_GPlus, P_WMinus, P_Hh, P_A, 1237, check)
      call createCurrent(P_cAnti, P_A, P_c, 1164, check)
      call createCurrent(P_A, P_Hh, P_Hl, P_A, 1577, check)
      call createCurrent(P_WPlus, P_G0, P_GMinus, P_Z, 690, check)
      call createCurrent(P_tauPlus, P_G0, P_tauMinus, 252, check)
      call createCurrent(P_Hl, P_A, P_A, P_Hl, 1554, check)
      call createCurrent(P_tauMinus, P_WPlus, P_nu_tauAnti, 172, check)
      call createCurrent(P_A, P_Hl, P_WPlus, P_GMinus, 823, check)
      call createCurrent(P_g, P_g, P_Hl, 1602, check)
      call createCurrent(P_A, P_GPlus, P_WMinus, P_G0, 166, check)
      call createCurrent(P_WMinus, P_ghZAnti, P_ghWp, 883, check)
      call createCurrent(P_nu_e, P_nu_eAnti, P_Z, 1061, check)
      call createCurrent(P_G0, P_WMinus, P_GPlus, P_Z, 71, check)
      call createCurrent(P_eMinus, P_ePlus, P_Hl, 964, check)
      call createCurrent(P_muMinus, P_muPlus, 1386, check)
      call createCurrent(P_Hh, P_WPlus, P_WMinus, P_Hh, 1377, check)
      call createCurrent(P_GPlus, P_WMinus, P_Z, P_Hh, 881, check)
      call createCurrent(P_A, P_A, P_GPlus, P_GMinus, 652, check)
      call createCurrent(P_bAnti, P_b, P_G0, 1056, check)
      call createCurrent(P_g, P_GMinus, P_GPlus, P_g, 1545, check)
      call createCurrent(P_Z, P_nu_tau, P_nu_tauAnti, 844, check)
      call createCurrent(P_ghWpAnti, P_GPlus, P_ghZ, 219, check)
      call createCurrent(P_GPlus, P_GMinus, P_Hh, P_Hl, 660, check)
      call createCurrent(P_WPlus, P_nu_muAnti, P_muMinus, 1116, check)
      call createCurrent(P_muMinus, P_muPlus, P_A, 903, check)
      call createCurrent(P_A, P_WMinus, P_GPlus, P_G0, 316, check)
      call createCurrent(P_dAnti, P_d, P_Z, 81, check)
      call createCurrent(P_Z, P_WMinus, P_Hl, P_GPlus, 1170, check)
      call createCurrent(P_G0, P_Hh, P_Hl, P_G0, 1165, check)
      call createCurrent(P_WMinus, P_c, P_sAnti, 621, check)
      call createCurrent(P_WMinus, P_WPlus, P_Hl, P_Hh, 1232, check)
      call createCurrent(P_GMinus, P_Hl, P_A, P_WPlus, 805, check)
      call createCurrent(P_A, P_Z, 1507, check)
      call createCurrent(P_Hl, P_WPlus, P_Hl, P_WMinus, 709, check)
      call createCurrent(P_WPlus, P_Hh, P_WMinus, 1314, check)
      call createCurrent(P_Z, P_GPlus, P_WMinus, P_G0, 333, check)
      call createCurrent(P_s, P_sAnti, P_Hh, 746, check)
      call createCurrent(P_G0, P_A, P_WMinus, P_GPlus, 718, check)
      call createCurrent(P_b, P_bAnti, P_G0, 478, check)
      call createCurrent(P_A, P_WPlus, P_WMinus, 1317, check)
      call createCurrent(P_GPlus, P_Hh, P_Hh, P_GMinus, 817, check)
      call createCurrent(P_tauPlus, P_A, P_tauMinus, 1248, check)
      call createCurrent(P_Z, P_Z, P_GPlus, P_GMinus, 1209, check)
      call createCurrent(P_WMinus, P_Hl, P_Z, P_GPlus, 323, check)
      call createCurrent(P_Hl, P_G0, P_Hl, P_G0, 965, check)
      call createCurrent(P_GMinus, P_Z, P_GPlus, P_A, 221, check)
      call createCurrent(P_bAnti, P_WMinus, P_t, 924, check)
      call createCurrent(P_WMinus, P_GPlus, P_A, 1345, check)
      call createCurrent(P_Hh, P_GMinus, P_A, P_WPlus, 398, check)
      call createCurrent(P_Z, P_A, P_Hh, P_Hh, 1471, check)
      call createCurrent(P_WPlus, P_Hl, P_WMinus, 100, check)
      call createCurrent(P_WPlus, P_A, P_WMinus, P_A, 501, check)
      call createCurrent(P_A, P_Z, P_Z, P_Z, 1647, check)
      call createCurrent(P_A, P_GPlus, P_WMinus, 868, check)
      call createCurrent(P_ghGAnti, P_g, P_ghG, 911, check)
      call createCurrent(P_s, P_cAnti, P_WPlus, 815, check)
      call createCurrent(P_Hl, P_WPlus, P_Z, P_GMinus, 227, check)
      call createCurrent(P_A, P_GMinus, P_WPlus, P_G0, 1238, check)
      call createCurrent(P_A, P_WMinus, P_WPlus, 327, check)
      call createCurrent(P_WMinus, P_Hl, P_WPlus, 326, check)
      call createCurrent(P_Hh, P_G0, P_G0, P_Hl, 65, check)
      call createCurrent(P_Z, P_A, P_Z, P_Z, 1662, check)
      call createCurrent(P_Z, P_Z, P_WPlus, P_WMinus, 86, check)
      call createCurrent(P_Hl, P_Z, P_WMinus, P_GPlus, 1337, check)
      call createCurrent(P_WPlus, P_b, P_tAnti, 312, check)
      call createCurrent(P_A, P_GMinus, P_GPlus, P_A, 694, check)
      call createCurrent(P_Hl, P_bAnti, P_b, 159, check)
      call createCurrent(P_ghA, P_GPlus, P_ghWpAnti, 1007, check)
      call createCurrent(P_Hh, P_Z, P_Hh, P_Z, 429, check)
      call createCurrent(P_WPlus, P_ghWm, P_ghZAnti, 848, check)
      call createCurrent(P_G0, P_Z, 1414, check)
      call createCurrent(P_nu_muAnti, P_A, P_nu_mu, 1510, check)
      call createCurrent(P_WMinus, P_Z, P_A, P_WPlus, 521, check)
      call createCurrent(P_GMinus, P_ghWmAnti, P_ghZ, 173, check)
      call createCurrent(P_GPlus, P_WMinus, P_Hl, 686, check)
      call createCurrent(P_Hl, P_GPlus, P_GMinus, 193, check)
      call createCurrent(P_Hl, P_WMinus, P_GPlus, P_Z, 772, check)
      call createCurrent(P_Z, P_g, P_g, P_Z, 1551, check)
      call createCurrent(P_GMinus, P_Z, P_Hl, P_WPlus, 1303, check)
      call createCurrent(P_nu_mu, P_A, P_nu_muAnti, 1506, check)
      call createCurrent(P_A, P_WPlus, P_WMinus, P_A, 1122, check)
      call createCurrent(P_Hl, P_Hl, P_Hh, P_Hh, 184, check)
      call createCurrent(P_GPlus, P_WMinus, P_WPlus, P_GMinus, 445, check)
      call createCurrent(P_GMinus, P_ghA, P_ghWmAnti, 1063, check)
      call createCurrent(P_G0, P_bAnti, P_b, 120, check)
      call createCurrent(P_Z, P_Z, P_Hl, P_Hl, 1175, check)
      call createCurrent(P_GMinus, P_WPlus, P_Hl, P_A, 691, check)
      call createCurrent(P_Z, P_WPlus, P_WMinus, P_A, 1104, check)
      call createCurrent(P_GMinus, P_WPlus, P_Z, P_Hl, 702, check)
      call createCurrent(P_G0, P_ghWp, P_ghWpAnti, 334, check)
      call createCurrent(P_GMinus, P_tauPlus, P_nu_tau, 957, check)
      call createCurrent(P_WMinus, P_Hh, P_WPlus, 123, check)
      call createCurrent(P_WPlus, P_WMinus, P_A, P_Z, 1130, check)
      call createCurrent(P_Hl, P_Hl, P_Z, P_A, 1389, check)
      call createCurrent(P_WMinus, P_Z, P_GPlus, P_Hh, 1197, check)
      call createCurrent(P_Hh, P_Hh, P_Hh, P_Hh, 1149, check)
      call createCurrent(P_WPlus, P_Z, P_GMinus, P_G0, 1304, check)
      call createCurrent(P_A, P_GMinus, P_G0, P_WPlus, 109, check)
      call createCurrent(P_Hh, P_Hh, P_WMinus, P_WPlus, 647, check)
      call createCurrent(P_g, P_g, P_Hl, P_Hh, 1615, check)
      call createCurrent(P_Z, P_Hl, P_G0, 829, check)
      call createCurrent(P_WMinus, P_A, P_A, P_WPlus, 1285, check)
      call createCurrent(P_WPlus, P_WMinus, P_Z, P_A, 274, check)
      call createCurrent(P_G0, P_Hl, P_G0, P_Hh, 1202, check)
      call createCurrent(P_A, P_G0, P_Z, P_G0, 1493, check)
      call createCurrent(P_WPlus, P_GMinus, P_Hh, 554, check)
      call createCurrent(P_WPlus, P_tAnti, P_b, 440, check)
      call createCurrent(P_A, P_GPlus, P_WMinus, P_Hl, 39, check)
      call createCurrent(P_nu_tauAnti, P_nu_tau, 1456, check)
      call createCurrent(P_GMinus, P_GPlus, 1433, check)
      call createCurrent(P_Hh, P_Z, P_G0, 1136, check)
      call createCurrent(P_nu_eAnti, P_WPlus, P_eMinus, 948, check)
      call createCurrent(P_Z, P_GPlus, P_WMinus, P_Hl, 337, check)
      call createCurrent(P_Z, P_WMinus, P_Z, P_WPlus, 731, check)
      call createCurrent(P_tauPlus, P_tauMinus, 1519, check)
      call createCurrent(P_A, P_g, P_g, P_Z, 1623, check)
      call createCurrent(P_WPlus, P_WMinus, P_Hl, P_Hl, 937, check)
      call createCurrent(P_WPlus, P_WMinus, P_Hl, 1186, check)
      call createCurrent(P_nu_tauAnti, P_nu_tau, P_Z, 1140, check)
      call createCurrent(P_tAnti, P_t, 1486, check)
      call createCurrent(P_g, P_Hh, P_g, 1635, check)
      call createCurrent(P_Hl, P_Z, P_Hh, P_Z, 555, check)
      call createCurrent(P_GMinus, P_G0, P_WPlus, P_A, 1095, check)
      call createCurrent(P_Z, P_u, P_uAnti, 106, check)
      call createCurrent(P_Hh, P_WMinus, P_WPlus, P_Hh, 1279, check)
      call createCurrent(P_Z, P_WPlus, P_WMinus, 130, check)
      call createCurrent(P_Z, P_nu_mu, P_nu_muAnti, 747, check)
      call createCurrent(P_Hh, P_A, P_Z, 1500, check)
      call createCurrent(P_WPlus, P_uAnti, P_d, 1309, check)
      call createCurrent(P_WMinus, P_GPlus, P_Hh, P_Z, 1057, check)
      call createCurrent(P_ghWp, P_GMinus, P_ghZAnti, 878, check)
      call createCurrent(P_G0, P_Z, P_Hh, 674, check)
      call createCurrent(P_GPlus, P_GMinus, P_Z, P_Z, 56, check)
      call createCurrent(P_Hl, P_Z, P_Hh, P_A, 1423, check)
      call createCurrent(P_Z, P_g, P_g, P_A, 1606, check)
      call createCurrent(P_Hh, P_WPlus, P_GMinus, P_A, 431, check)
      call createCurrent(P_A, P_Hh, P_Z, P_Hh, 1383, check)
      call createCurrent(P_uAnti, P_A, P_u, 1071, check)
      call createCurrent(P_uAnti, P_WPlus, P_d, 466, check)
      call createCurrent(P_Z, P_A, P_GMinus, P_GPlus, 735, check)
      call createCurrent(P_G0, P_G0, P_Hl, 1046, check)
      call createCurrent(P_WPlus, P_Hl, P_Z, P_GMinus, 1054, check)
      call createCurrent(P_WPlus, P_A, P_Z, P_WMinus, 210, check)
      call createCurrent(P_Hl, P_ghWm, P_ghWmAnti, 684, check)
      call createCurrent(P_ghZAnti, P_Hl, P_ghZ, 894, check)
      call createCurrent(P_g, P_g, P_A, P_g, 1652, check)
      call createCurrent(P_Z, P_WPlus, P_GMinus, P_Hh, 531, check)
      call createCurrent(P_sAnti, P_c, P_GMinus, 871, check)
      call createCurrent(P_A, P_GMinus, P_GPlus, P_Z, 809, check)
      call createCurrent(P_WMinus, P_t, P_bAnti, 1022, check)
      call createCurrent(P_WMinus, P_Z, P_GPlus, 545, check)
      call createCurrent(P_A, P_nu_eAnti, P_nu_e, 1524, check)
      call createCurrent(P_c, P_cAnti, P_Hl, 73, check)
      call createCurrent(P_G0, P_Hl, P_Hl, P_G0, 515, check)
      call createCurrent(P_WPlus, P_Hh, P_GMinus, P_Z, 512, check)
      call createCurrent(P_nu_e, P_nu_eAnti, 1449, check)
      call createCurrent(P_ghWp, P_ghWpAnti, P_Z, 1131, check)
      call createCurrent(P_nu_eAnti, P_Z, P_nu_e, 66, check)
      call createCurrent(P_Hh, P_Z, P_A, P_Hh, 1499, check)
      call createCurrent(P_Hl, P_dAnti, P_d, 514, check)
      call createCurrent(P_b, P_Z, P_bAnti, 804, check)
      call createCurrent(P_d, P_dAnti, P_G0, 118, check)
      call createCurrent(P_cAnti, P_WPlus, P_s, 336, check)
      call createCurrent(P_ghAAnti, P_WMinus, P_ghWp, 1081, check)
      call createCurrent(P_GMinus, P_GPlus, P_A, P_A, 1205, check)
      call createCurrent(P_d, P_uAnti, P_WPlus, 856, check)
      call createCurrent(P_Hl, P_Hh, P_GPlus, P_GMinus, 321, check)
      call createCurrent(P_Hl, P_GMinus, P_A, P_WPlus, 213, check)
      call createCurrent(P_GPlus, P_WPlus, P_GMinus, P_WMinus, 781, check)
      call createCurrent(P_tauPlus, P_WMinus, P_nu_tau, 467, check)
      call createCurrent(P_b, P_tAnti, P_WPlus, 154, check)
      call createCurrent(P_ghAAnti, P_ghWp, P_WMinus, 713, check)
      call createCurrent(P_ghWm, P_WPlus, P_ghZAnti, 728, check)
      call createCurrent(P_GPlus, P_Hl, P_WMinus, P_Z, 1221, check)
      call createCurrent(P_Hl, P_WMinus, P_Hl, P_WPlus, 290, check)
      call createCurrent(P_ghWmAnti, P_ghA, P_WMinus, 506, check)
      call createCurrent(P_Hh, P_A, P_GMinus, P_WPlus, 656, check)
      call createCurrent(P_A, P_nu_mu, P_nu_muAnti, 1511, check)
      call createCurrent(P_A, P_G0, P_A, P_G0, 1674, check)
      call createCurrent(P_Hl, P_Z, P_WPlus, P_GMinus, 527, check)
      call createCurrent(P_G0, P_b, P_bAnti, 1187, check)
      call createCurrent(P_ghWm, P_GPlus, P_ghZAnti, 710, check)
      call createCurrent(P_G0, P_GMinus, P_A, P_WPlus, 439, check)
      call createCurrent(P_WMinus, P_A, P_GPlus, P_Hh, 614, check)
      call createCurrent(P_Hh, P_ghWmAnti, P_ghWm, 266, check)
      call createCurrent(P_ghAAnti, P_ghWm, P_WPlus, 97, check)
      call createCurrent(P_WPlus, P_WMinus, P_WPlus, P_WMinus, 821, check)
      call createCurrent(P_WPlus, P_Z, P_Hl, P_GMinus, 785, check)
      call createCurrent(P_WMinus, P_Hh, P_WPlus, P_Hl, 121, check)
      call createCurrent(P_Hl, P_ghWpAnti, P_ghWp, 1342, check)
      call createCurrent(P_nu_tau, P_Z, P_nu_tauAnti, 343, check)
      call createCurrent(P_G0, P_Hl, P_Z, 541, check)
      call createCurrent(P_WPlus, P_Z, P_WMinus, P_A, 751, check)
      call createCurrent(P_Hl, P_g, P_Hh, P_g, 1593, check)
      call createCurrent(P_A, P_nu_e, P_nu_eAnti, 1409, check)
      call createCurrent(P_ghZAnti, P_ghZ, P_Hl, 697, check)
      call createCurrent(P_bAnti, P_t, P_WMinus, 683, check)
      call createCurrent(P_Hl, P_Z, P_Hl, P_Z, 589, check)
      call createCurrent(P_GPlus, P_Z, P_WMinus, P_G0, 260, check)
      call createCurrent(P_WMinus, P_Hh, P_GPlus, P_Z, 962, check)
      call createCurrent(P_WPlus, P_eMinus, P_nu_eAnti, 777, check)
      call createCurrent(P_tAnti, P_WPlus, P_b, 186, check)
      call createCurrent(P_WMinus, P_ghAAnti, P_ghWp, 984, check)
      call createCurrent(P_tauPlus, P_GMinus, P_nu_tau, 858, check)
      call createCurrent(P_G0, P_A, P_A, P_G0, 1542, check)
      call createCurrent(P_ghWp, P_ghZAnti, P_WMinus, 827, check)
      call createCurrent(P_g, P_Hl, P_g, P_Hh, 1617, check)
      call createCurrent(P_Hh, P_GPlus, P_GMinus, P_Hl, 75, check)
      call createCurrent(P_nu_eAnti, P_nu_e, P_A, 1458, check)
      call createCurrent(P_Hl, P_WPlus, P_WMinus, 1334, check)
      call createCurrent(P_nu_tauAnti, P_tauMinus, P_GPlus, 1275, check)
      call createCurrent(P_WPlus, P_GMinus, P_Z, 491, check)
      call createCurrent(P_A, P_ghWpAnti, P_ghWp, 443, check)
      call createCurrent(P_G0, P_G0, P_Hl, P_Hh, 897, check)
      call createCurrent(P_ghZAnti, P_Hh, P_ghZ, 1382, check)
      call createCurrent(P_GPlus, P_d, P_uAnti, 176, check)
      call createCurrent(P_eMinus, P_ePlus, 1411, check)
      call createCurrent(P_GMinus, P_Z, P_WPlus, 1347, check)
      call createCurrent(P_Z, P_GMinus, P_GPlus, P_Z, 532, check)
      call createCurrent(P_G0, P_Hl, P_Hh, P_G0, 987, check)
      call createCurrent(P_Hl, P_g, P_g, 1568, check)
      call createCurrent(P_ghWm, P_Z, P_ghWmAnti, 392, check)
      call createCurrent(P_A, P_WMinus, P_WPlus, P_Z, 1299, check)
      call createCurrent(P_Z, P_A, P_WMinus, P_WPlus, 507, check)
      call createCurrent(P_A, P_Z, P_GMinus, P_GPlus, 928, check)
      call createCurrent(P_A, P_tAnti, P_t, 31, check)
      call createCurrent(P_WPlus, P_Hl, P_GMinus, 717, check)
      call createCurrent(P_G0, P_GPlus, P_WMinus, 933, check)
      call createCurrent(P_GPlus, P_nu_tauAnti, P_tauMinus, 265, check)
      call createCurrent(P_GPlus, P_Z, P_GMinus, P_A, 1106, check)
      call createCurrent(P_WMinus, P_Hh, P_GPlus, 62, check)
      call createCurrent(P_Hl, P_GMinus, P_GPlus, P_Hh, 847, check)
      call createCurrent(P_Z, P_d, P_dAnti, 201, check)
      call createCurrent(P_eMinus, P_ePlus, P_Hh, 475, check)
      call createCurrent(P_ghWmAnti, P_ghZ, P_GMinus, 535, check)
      call createCurrent(P_Z, P_A, P_GPlus, P_GMinus, 1193, check)
      call createCurrent(P_WMinus, P_WPlus, P_WPlus, P_WMinus, 322, check)
      call createCurrent(P_GMinus, P_c, P_sAnti, 447, check)
      call createCurrent(P_g, P_c, P_cAnti, 544, check)
      call createCurrent(P_ghWpAnti, P_ghWp, P_A, 208, check)
      call createCurrent(P_Hh, P_Z, P_A, 1420, check)
      call createCurrent(P_GMinus, P_WPlus, P_Hh, 428, check)
      call createCurrent(P_WPlus, P_WMinus, P_GPlus, P_GMinus, 1181, check)
      call createCurrent(P_WMinus, P_GPlus, P_A, P_Hl, 960, check)
      call createCurrent(P_cAnti, P_s, P_WPlus, 1086, check)
      call createCurrent(P_WPlus, P_GPlus, P_WMinus, P_GMinus, 1089, check)
      call createCurrent(P_Hh, P_dAnti, P_d, 571, check)
      call createCurrent(P_ghWmAnti, P_ghWm, P_A, 1333, check)
      call createCurrent(P_s, P_Hh, P_sAnti, 277, check)
      call createCurrent(P_G0, P_GPlus, P_G0, P_GMinus, 119, check)
      call createCurrent(P_GMinus, P_G0, P_Z, P_WPlus, 253, check)
      call createCurrent(P_WMinus, P_GPlus, 1412, check)
      call createCurrent(P_g, P_sAnti, P_s, 552, check)
      call createCurrent(P_Z, P_Hl, P_Hh, P_A, 1473, check)
      call createCurrent(P_A, P_A, P_Hh, P_Hh, 1576, check)
      call createCurrent(P_ePlus, P_nu_e, P_WMinus, 841, check)
      call createCurrent(P_GMinus, P_WPlus, 1452, check)
      call createCurrent(P_nu_tauAnti, P_nu_tau, P_A, 1399, check)
      call createCurrent(P_WMinus, P_A, P_GPlus, 1247, check)
      call createCurrent(P_A, P_t, P_tAnti, 680, check)
      call createCurrent(P_b, P_G0, P_bAnti, 1266, check)
      call createCurrent(P_nu_tau, P_GMinus, P_tauPlus, 1210, check)
      call createCurrent(P_Z, P_Hl, P_Hl, P_Z, 216, check)
      call createCurrent(P_WMinus, P_GPlus, P_Hl, P_A, 617, check)
      call createCurrent(P_Hh, P_WMinus, P_GPlus, P_Z, 797, check)
      call createCurrent(P_Z, P_WPlus, P_GMinus, 1242, check)
      call createCurrent(P_ghWpAnti, P_Z, P_ghWp, 263, check)
      call createCurrent(P_Hl, P_WMinus, P_GPlus, 715, check)
      call createCurrent(P_A, P_Z, P_Hh, P_Hl, 1451, check)
      call createCurrent(P_Z, P_s, P_sAnti, 458, check)
      call createCurrent(P_nu_tau, P_WMinus, P_tauPlus, 259, check)
      call createCurrent(P_WPlus, P_ghZAnti, P_ghWm, 887, check)
      call createCurrent(P_GPlus, P_GMinus, P_GPlus, P_GMinus, 866, check)
      call createCurrent(P_GPlus, P_GMinus, P_A, P_A, 550, check)
      call createCurrent(P_sAnti, P_s, P_g, 657, check)
      call createCurrent(P_G0, P_Hh, P_G0, P_Hh, 572, check)
      call createCurrent(P_A, P_g, P_Z, P_g, 1553, check)
      call createCurrent(P_WPlus, P_WPlus, P_WMinus, P_WMinus, 1308, check)
      call createCurrent(P_GPlus, P_WMinus, P_A, 258, check)
      call createCurrent(P_ePlus, P_Hl, P_eMinus, 505, check)
      call createCurrent(P_tAnti, P_t, P_g, 272, check)
      call createCurrent(P_Hl, P_GPlus, P_GMinus, P_Hl, 622, check)
      call createCurrent(P_A, P_WPlus, P_GMinus, P_Hh, 386, check)
      call createCurrent(P_GPlus, P_ghZ, P_ghWpAnti, 926, check)
      call createCurrent(P_GMinus, P_Hh, P_GPlus, 229, check)
      call createCurrent(P_t, P_tAnti, P_Hl, 19, check)
      call createCurrent(P_WMinus, P_ghWp, P_ghZAnti, 155, check)
      call createCurrent(P_GMinus, P_WPlus, P_GPlus, P_WMinus, 80, check)
      call createCurrent(P_eMinus, P_ePlus, P_G0, 682, check)
      call createCurrent(P_WPlus, P_GMinus, P_A, P_G0, 654, check)
      call createCurrent(P_g, P_g, P_g, 1033, check)
      call createCurrent(P_GPlus, P_WMinus, P_G0, 1151, check)
      call createCurrent(P_GMinus, P_GPlus, P_Z, P_A, 9, check)
      call createCurrent(P_uAnti, P_u, P_Z, 511, check)
      call createCurrent(P_GMinus, P_G0, P_GPlus, P_G0, 67, check)
      call createCurrent(P_GPlus, P_WMinus, P_Hh, 1003, check)
      call createCurrent(P_ghWp, P_ghZAnti, P_GMinus, 1287, check)
      call createCurrent(P_Z, P_WMinus, P_WPlus, P_Z, 1102, check)
      call createCurrent(P_WPlus, P_ghWpAnti, P_ghA, 626, check)
      call createCurrent(P_g, P_Hl, P_Hh, P_g, 1571, check)
      call createCurrent(P_nu_mu, P_Z, P_nu_muAnti, 411, check)
      call createCurrent(P_GMinus, P_GPlus, P_GPlus, P_GMinus, 359, check)
      call createCurrent(P_u, P_WMinus, P_dAnti, 898, check)
      call createCurrent(P_Z, P_WMinus, P_GPlus, 235, check)
      call createCurrent(P_ghG, P_g, P_ghGAnti, 540, check)
      call createCurrent(P_GPlus, P_WMinus, P_Z, P_Hl, 1364, check)
      call createCurrent(P_tauPlus, P_Hh, P_tauMinus, 1084, check)
      call createCurrent(P_tauMinus, P_Z, P_tauPlus, 1226, check)
      call createCurrent(P_A, P_g, P_g, P_A, 1563, check)
      call createCurrent(P_GMinus, P_nu_mu, P_muPlus, 418, check)
      call createCurrent(P_WPlus, P_WMinus, P_GMinus, P_GPlus, 982, check)
      call createCurrent(P_A, P_bAnti, P_b, 79, check)
      call createCurrent(P_GPlus, P_GMinus, P_Hh, P_Hh, 198, check)
      call createCurrent(P_G0, P_G0, P_A, P_Z, 1518, check)
      call createCurrent(P_Hh, P_Z, P_Z, P_Hl, 624, check)
      call createCurrent(P_ePlus, P_eMinus, 1502, check)
      call createCurrent(P_nu_tau, P_nu_tauAnti, P_Z, 293, check)
      call createCurrent(P_ghWmAnti, P_WMinus, P_ghA, 291, check)
      call createCurrent(P_WPlus, P_GMinus, P_Hl, P_Z, 730, check)
      call createCurrent(P_Hl, P_tauMinus, P_tauPlus, 811, check)
      call createCurrent(P_A, P_Z, P_Hh, 1454, check)
      call createCurrent(P_ghWpAnti, P_ghZ, P_GPlus, 1125, check)
      call createCurrent(P_Hh, P_b, P_bAnti, 927, check)
      call createCurrent(P_g, P_Z, P_g, P_g, 1604, check)
      call createCurrent(P_Z, P_tauMinus, P_tauPlus, 1252, check)
      call createCurrent(P_ghWp, P_ghWpAnti, P_A, 131, check)
      call createCurrent(P_Z, P_A, P_WPlus, P_WMinus, 836, check)
      call createCurrent(P_Hl, P_Hl, P_Hl, P_Hh, 585, check)
      call createCurrent(P_GMinus, P_A, P_WPlus, P_G0, 1346, check)
      call createCurrent(P_WPlus, P_WMinus, P_Hh, 502, check)
      call createCurrent(P_GMinus, P_Hl, P_Hl, P_GPlus, 449, check)
      call createCurrent(P_ghZ, P_GMinus, P_ghWmAnti, 549, check)
      call createCurrent(P_WPlus, P_WMinus, P_Hl, P_Hh, 170, check)
      call createCurrent(P_WMinus, P_Hh, P_GPlus, P_A, 16, check)
      call createCurrent(P_A, P_A, P_G0, P_G0, 1582, check)
      call createCurrent(P_Hl, P_Hh, P_Hl, 786, check)
      call createCurrent(P_G0, P_tauMinus, P_tauPlus, 352, check)
      call createCurrent(P_A, P_A, P_Hl, P_Hl, 1600, check)
      call createCurrent(P_nu_muAnti, P_nu_mu, 1523, check)
      call createCurrent(P_G0, P_s, P_sAnti, 278, check)
      call createCurrent(P_g, P_ghG, P_ghGAnti, 372, check)
      call createCurrent(P_bAnti, P_b, P_Hl, 818, check)
      call createCurrent(P_Hl, P_WPlus, P_A, P_GMinus, 967, check)
      call createCurrent(P_muMinus, P_muPlus, P_Hl, 899, check)
      call createCurrent(P_ghAAnti, P_WPlus, P_ghWm, 1146, check)
      call createCurrent(P_nu_tau, P_nu_tauAnti, 1429, check)
      call createCurrent(P_WMinus, P_Hl, P_GPlus, 968, check)
      call createCurrent(P_Z, P_muPlus, P_muMinus, 54, check)
      call createCurrent(P_WMinus, P_WPlus, P_G0, P_G0, 226, check)
      call createCurrent(P_Z, P_g, P_A, P_g, 1539, check)
      call createCurrent(P_tAnti, P_t, P_G0, 165, check)
      call createCurrent(P_G0, P_ghWmAnti, P_ghWm, 595, check)
      call createCurrent(P_WPlus, P_Hl, P_A, P_GMinus, 1043, check)
      call createCurrent(P_Hh, P_G0, P_G0, P_Hh, 289, check)
      call createCurrent(P_b, P_bAnti, P_Hh, 790, check)
      call createCurrent(P_s, P_G0, P_sAnti, 1128, check)
      call createCurrent(P_Hl, P_A, P_Hl, P_A, 1533, check)
      call createCurrent(P_GMinus, P_ghWp, P_ghZAnti, 659, check)
      call createCurrent(P_Z, P_Z, P_Hh, P_Hh, 92, check)
      call createCurrent(P_Hh, P_G0, P_G0, 145, check)
      call createCurrent(P_nu_tauAnti, P_tauMinus, P_WPlus, 721, check)
      call createCurrent(P_nu_e, P_nu_eAnti, P_A, 1521, check)
      call createCurrent(P_Hh, P_G0, P_Hl, P_G0, 185, check)
      call createCurrent(P_WPlus, P_Hh, P_WMinus, P_Hl, 99, check)
      call createCurrent(P_A, P_Z, P_GPlus, P_GMinus, 1021, check)
      call createCurrent(P_d, P_A, P_dAnti, 369, check)
      call createCurrent(P_Hh, P_WPlus, P_GMinus, P_Z, 410, check)
      call createCurrent(P_GPlus, P_G0, P_WMinus, 1107, check)
      call createCurrent(P_GMinus, P_WPlus, P_Hl, P_Z, 1147, check)
      call createCurrent(P_WMinus, P_GPlus, P_G0, P_Z, 1160, check)
      call createCurrent(P_g, P_g, P_Z, P_A, 1605, check)
      call createCurrent(P_Hh, P_Hl, P_Z, P_A, 1482, check)
      call createCurrent(P_ghZ, P_Hh, P_ghZAnti, 619, check)
      call createCurrent(P_WPlus, P_Hh, P_GMinus, 1034, check)
      call createCurrent(P_Z, P_Z, P_Hl, P_Hh, 361, check)
      call createCurrent(P_A, P_WPlus, P_WMinus, P_Z, 211, check)
      call createCurrent(P_GMinus, P_GPlus, P_Hh, 567, check)
      call createCurrent(P_A, P_WPlus, P_GMinus, 1269, check)
      call createCurrent(P_WMinus, P_A, P_Hl, P_GPlus, 393, check)
      call createCurrent(P_tAnti, P_A, P_t, 408, check)
      call createCurrent(P_Z, P_G0, P_A, P_G0, 1392, check)
      call createCurrent(P_c, P_WMinus, P_sAnti, 228, check)
      call createCurrent(P_u, P_Z, P_uAnti, 484, check)
      call createCurrent(P_g, P_GPlus, P_g, P_GMinus, 1650, check)
      call createCurrent(P_Hh, P_GMinus, P_Z, P_WPlus, 598, check)
      call createCurrent(P_WPlus, P_GMinus, P_Hh, P_A, 831, check)
      call createCurrent(P_s, P_sAnti, P_A, 461, check)
      call createCurrent(P_t, P_tAnti, P_g, 1331, check)
      call createCurrent(P_WMinus, P_Hh, P_Hl, P_WPlus, 249, check)
      call createCurrent(P_GPlus, P_ghA, P_ghWpAnti, 144, check)
      call createCurrent(P_Hl, P_GMinus, P_WPlus, P_A, 405, check)
      call createCurrent(P_Z, P_bAnti, P_b, 1355, check)
      call createCurrent(P_Z, P_A, P_Z, P_A, 1659, check)
      call createCurrent(P_G0, P_GPlus, P_Z, P_WMinus, 368, check)
      call createCurrent(P_G0, P_WPlus, P_GMinus, P_A, 939, check)
      call createCurrent(P_A, P_GPlus, P_WMinus, P_Hh, 182, check)
      call createCurrent(P_Z, P_dAnti, P_d, 915, check)
      call createCurrent(P_A, P_WMinus, P_A, P_WPlus, 1180, check)
      call createCurrent(P_ghWpAnti, P_ghWp, P_Hl, 171, check)
      call createCurrent(P_Hl, P_GMinus, P_Hl, P_GPlus, 1075, check)
      call createCurrent(P_bAnti, P_b, P_Z, 305, check)
      call createCurrent(P_sAnti, P_Hh, P_s, 1082, check)
      call createCurrent(P_A, P_c, P_cAnti, 417, check)
      call createCurrent(P_Z, P_Hh, P_G0, 345, check)
      call createCurrent(P_A, P_uAnti, P_u, 1255, check)
      call createCurrent(P_A, P_GPlus, P_GMinus, P_A, 990, check)
      call createCurrent(P_GPlus, P_Z, P_GMinus, 708, check)
      call createCurrent(P_GMinus, P_Z, P_GPlus, P_Z, 1185, check)
      call createCurrent(P_Hl, P_Hl, 1416, check)
      call createCurrent(P_Z, P_g, P_Z, P_g, 1583, check)
      call createCurrent(P_uAnti, P_u, 1436, check)
      call createCurrent(P_b, P_A, P_bAnti, 1053, check)
      call createCurrent(P_eMinus, P_nu_eAnti, P_WPlus, 8, check)
      call createCurrent(P_Hh, P_WMinus, P_WPlus, P_Hl, 941, check)
      call createCurrent(P_s, P_g, P_sAnti, 1, check)
      call createCurrent(P_G0, P_G0, P_Z, P_Z, 192, check)
      call createCurrent(P_Hl, P_Hl, P_GPlus, P_GMinus, 934, check)
      call createCurrent(P_Z, P_GMinus, P_WPlus, 538, check)
      call createCurrent(P_Z, P_GMinus, P_Hl, P_WPlus, 1217, check)
      call createCurrent(P_A, P_g, P_g, P_g, 1547, check)
      call createCurrent(P_nu_e, P_GMinus, P_ePlus, 672, check)
      call createCurrent(P_Hl, P_GMinus, P_GPlus, 661, check)
      call createCurrent(P_b, P_Hh, P_bAnti, 1103, check)
      call createCurrent(P_Hh, P_WPlus, P_WMinus, 1068, check)
      call createCurrent(P_dAnti, P_d, 1403, check)
      call createCurrent(P_GMinus, P_WPlus, P_Z, P_G0, 1292, check)
      call createCurrent(P_Hh, P_Z, P_Hh, P_A, 1487, check)
      call createCurrent(P_s, P_sAnti, P_Z, 1070, check)
      call createCurrent(P_Z, P_ghWm, P_ghWmAnti, 855, check)
      call createCurrent(P_Z, P_WPlus, P_GMinus, P_Hl, 1265, check)
      call createCurrent(P_Z, P_G0, P_Hl, 1235, check)
      call createCurrent(P_Z, P_Hh, P_WMinus, P_GPlus, 500, check)
      call createCurrent(P_Hh, P_G0, P_Hh, P_G0, 1141, check)
      call createCurrent(P_g, P_d, P_dAnti, 22, check)
      call createCurrent(P_Hl, P_Hl, P_A, P_Z, 1434, check)
      call createCurrent(P_cAnti, P_g, P_c, 41, check)
      call createCurrent(P_A, P_cAnti, P_c, 603, check)
      call createCurrent(P_GMinus, P_Z, P_A, P_GPlus, 1251, check)
      call createCurrent(P_g, P_tAnti, P_t, 148, check)
      call createCurrent(P_Hh, P_A, P_Hh, P_A, 1531, check)
      call createCurrent(P_cAnti, P_Hl, P_c, 487, check)
      call createCurrent(P_WPlus, P_WMinus, P_G0, P_G0, 353, check)
      call createCurrent(P_A, P_Z, P_A, P_A, 1550, check)
      call createCurrent(P_ghWm, P_ghWmAnti, P_Hl, 161, check)
      call createCurrent(P_d, P_uAnti, P_GPlus, 282, check)
      call createCurrent(P_Z, P_Z, P_Z, P_Z, 1594, check)
      call createCurrent(P_Hh, P_Hl, P_A, P_Z, 1489, check)
      call createCurrent(P_Hh, P_WPlus, P_Hh, P_WMinus, 764, check)
      call createCurrent(P_t, P_g, P_tAnti, 800, check)
      call createCurrent(P_Z, P_Hh, P_Hh, P_Z, 225, check)
      call createCurrent(P_ghWmAnti, P_ghA, P_GMinus, 255, check)
      call createCurrent(P_ghG, P_ghGAnti, P_g, 406, check)
      call createCurrent(P_WPlus, P_Hl, P_GMinus, P_Z, 152, check)
      call createCurrent(P_GMinus, P_ghZAnti, P_ghWp, 15, check)
      call createCurrent(P_Hh, P_Z, P_Hl, P_A, 1438, check)
      call createCurrent(P_G0, P_WPlus, P_Z, P_GMinus, 35, check)
      call createCurrent(P_WPlus, P_A, P_A, P_WMinus, 1163, check)
      call createCurrent(P_Hl, P_A, P_Z, P_Hl, 1529, check)
      call createCurrent(P_ghA, P_WPlus, P_ghWpAnti, 1062, check)
      call createCurrent(P_G0, P_u, P_uAnti, 616, check)
      call createCurrent(P_Hl, P_d, P_dAnti, 1171, check)
      call createCurrent(P_u, P_Hh, P_uAnti, 808, check)
      call createCurrent(P_muPlus, P_muMinus, 1530, check)
      call createCurrent(P_tauPlus, P_tauMinus, P_A, 905, check)
      call createCurrent(P_WMinus, P_GPlus, P_Z, 1065, check)
      call createCurrent(P_GMinus, P_Hh, P_Hl, P_GPlus, 1199, check)
      call createCurrent(P_WMinus, P_A, P_GPlus, P_Hl, 1097, check)
      call createCurrent(P_GMinus, P_Z, P_WPlus, P_Hl, 276, check)
      call createCurrent(P_uAnti, P_G0, P_u, 1087, check)
      call createCurrent(P_Z, P_nu_muAnti, P_nu_mu, 1359, check)
      call createCurrent(P_Hh, P_WMinus, P_GPlus, P_A, 819, check)
      call createCurrent(P_A, P_ghWmAnti, P_ghWm, 610, check)
      call createCurrent(P_Z, P_A, P_Hh, P_Hl, 1527, check)
      call createCurrent(P_GMinus, P_WPlus, P_Hl, 474, check)
      call createCurrent(P_WMinus, P_GPlus, P_G0, P_A, 247, check)
      call createCurrent(P_Hl, P_ghZAnti, P_ghZ, 1078, check)
      call createCurrent(P_ghWmAnti, P_WMinus, P_ghZ, 1002, check)
      call createCurrent(P_d, P_Hl, P_dAnti, 704, check)
      call createCurrent(P_Hh, P_A, P_Hl, P_A, 1629, check)
      call createCurrent(P_Hl, P_u, P_uAnti, 761, check)
      call createCurrent(P_WPlus, P_WMinus, P_g, P_g, 1569, check)
      call createCurrent(P_Z, P_G0, P_GPlus, P_WMinus, 569, check)
      call createCurrent(P_Hl, P_ghWp, P_ghWpAnti, 1330, check)
      call createCurrent(P_Z, P_b, P_bAnti, 954, check)
      call createCurrent(P_GMinus, P_G0, P_WPlus, P_Z, 607, check)
      call createCurrent(P_muMinus, P_Hl, P_muPlus, 969, check)
      call createCurrent(P_WPlus, P_G0, P_Z, P_GMinus, 851, check)
      call createCurrent(P_Z, P_GMinus, P_G0, P_WPlus, 177, check)
      call createCurrent(P_GPlus, P_A, P_GMinus, 820, check)
      call createCurrent(P_WMinus, P_nu_e, P_ePlus, 945, check)
      call createCurrent(P_WMinus, P_GPlus, P_Hh, 1366, check)
      call createCurrent(P_g, P_u, P_uAnti, 1325, check)
      call createCurrent(P_eMinus, P_A, P_ePlus, 68, check)
      call createCurrent(P_A, P_Hh, P_Hh, P_Z, 1410, check)
      call createCurrent(P_nu_tauAnti, P_Z, P_nu_tau, 1101, check)
      call createCurrent(P_nu_muAnti, P_GPlus, P_muMinus, 267, check)
      call createCurrent(P_GPlus, P_GMinus, P_Z, 839, check)
      call createCurrent(P_Hl, P_Hh, P_WMinus, P_WPlus, 793, check)
      call createCurrent(P_g, P_Hl, P_g, P_Hl, 1591, check)
      call createCurrent(P_WMinus, P_GPlus, P_Hl, P_Z, 1080, check)
      call createCurrent(P_G0, P_GMinus, P_GPlus, P_G0, 136, check)
      call createCurrent(P_A, P_GMinus, P_A, P_GPlus, 0, check)
      call createCurrent(P_g, P_g, P_GMinus, P_GPlus, 1640, check)
      call createCurrent(P_Z, P_Hh, P_Z, P_Hh, 308, check)
      call createCurrent(P_sAnti, P_s, P_A, 961, check)
      call createCurrent(P_eMinus, P_ePlus, P_Z, 452, check)
      call createCurrent(P_Hh, P_GPlus, P_GMinus, 602, check)
      call createCurrent(P_G0, P_Z, P_GPlus, P_WMinus, 983, check)
      call createCurrent(P_s, P_sAnti, P_Hl, 234, check)
      call createCurrent(P_G0, P_G0, P_WPlus, P_WMinus, 421, check)
      call createCurrent(P_GMinus, P_ePlus, P_nu_e, 88, check)
      call createCurrent(P_G0, P_A, P_GPlus, P_WMinus, 825, check)
      call createCurrent(P_t, P_tAnti, P_Hh, 1368, check)
      call createCurrent(P_ghZ, P_ghWpAnti, P_WPlus, 1026, check)
      call createCurrent(P_WPlus, P_ghAAnti, P_ghWm, 105, check)
      call createCurrent(P_cAnti, P_c, P_g, 1044, check)
      call createCurrent(P_GPlus, P_ghZAnti, P_ghWm, 794, check)
      call createCurrent(P_dAnti, P_Hh, P_d, 1223, check)
      call createCurrent(P_GMinus, P_G0, P_G0, P_GPlus, 402, check)
      call createCurrent(P_WMinus, P_WPlus, P_g, P_g, 1574, check)
      call createCurrent(P_A, P_g, P_A, P_g, 1621, check)
      call createCurrent(P_A, P_sAnti, P_s, 889, check)
      call createCurrent(P_Z, P_ghWp, P_ghWpAnti, 243, check)
      call createCurrent(P_d, P_dAnti, P_Z, 64, check)
      call createCurrent(P_g, P_g, P_Hh, 1561, check)
      call createCurrent(P_tauPlus, P_tauMinus, P_Hh, 592, check)
      call createCurrent(P_Hh, P_d, P_dAnti, 604, check)
      call createCurrent(P_WPlus, P_ghWm, P_ghAAnti, 1064, check)
      call createCurrent(P_cAnti, P_s, P_GPlus, 739, check)
      call createCurrent(P_G0, P_A, P_GMinus, P_WPlus, 271, check)
      call createCurrent(P_Z, P_A, P_g, P_g, 1654, check)
      call createCurrent(P_u, P_Hl, P_uAnti, 1373, check)
      call createCurrent(P_Z, P_GMinus, P_A, P_GPlus, 1231, check)
      call createCurrent(P_GMinus, P_u, P_dAnti, 1228, check)
      call createCurrent(P_Hh, P_WPlus, P_Hl, P_WMinus, 191, check)
      call createCurrent(P_Z, P_ghWpAnti, P_ghWp, 139, check)
      call createCurrent(P_Hh, P_Z, P_GMinus, P_WPlus, 38, check)
      call createCurrent(P_WMinus, P_G0, P_WPlus, P_G0, 1094, check)
      call createCurrent(P_A, P_Z, P_Hl, 1462, check)
      call createCurrent(P_Hh, P_Z, P_Hl, P_Z, 999, check)
      call createCurrent(P_Hh, P_Hh, P_Hh, P_Hl, 203, check)
      call createCurrent(P_nu_e, P_A, P_nu_eAnti, 1479, check)
      call createCurrent(P_WPlus, P_Z, P_WMinus, P_Z, 96, check)
      call createCurrent(P_sAnti, P_G0, P_s, 882, check)
      call createCurrent(P_ghGAnti, P_ghG, P_g, 251, check)
      call createCurrent(P_Hh, P_G0, P_Z, 1001, check)
      call createCurrent(P_Hl, P_WMinus, P_GPlus, P_A, 539, check)
      call createCurrent(P_muMinus, P_Z, P_muPlus, 716, check)
      call createCurrent(P_G0, P_G0, P_WMinus, P_WPlus, 543, check)
      call createCurrent(P_GMinus, P_Hh, P_WPlus, P_Z, 32, check)
      call createCurrent(P_Hl, P_g, P_Hl, P_g, 1541, check)
      call createCurrent(P_b, P_bAnti, P_A, 470, check)
      call createCurrent(P_Hl, P_Z, P_Z, P_Hh, 1112, check)
      call createCurrent(P_A, P_G0, 1388, check)
      call createCurrent(P_WMinus, P_ghWmAnti, P_ghZ, 1050, check)
      call createCurrent(P_A, P_Z, P_Hh, P_Hh, 1413, check)
      call createCurrent(P_A, P_Hh, P_GPlus, P_WMinus, 517, check)
      call createCurrent(P_Hl, P_WMinus, P_WPlus, P_Hh, 625, check)
      call createCurrent(P_WMinus, P_GPlus, P_GMinus, P_WPlus, 34, check)
      call createCurrent(P_Hl, P_Hh, P_Hh, 822, check)
      call createCurrent(P_g, P_g, P_g, P_g, 1108, check)
      call createCurrent(P_tAnti, P_b, P_WPlus, 651, check)
      call createCurrent(P_G0, P_Hh, P_G0, P_Hl, 101, check)
      call createCurrent(P_nu_eAnti, P_eMinus, P_WPlus, 1120, check)
      call createCurrent(P_bAnti, P_b, P_Hh, 562, check)
      call createCurrent(P_Hh, P_GMinus, P_Hh, P_GPlus, 950, check)
      call createCurrent(P_g, P_WMinus, P_WPlus, P_g, 1573, check)
      call createCurrent(P_A, P_GPlus, P_Z, P_GMinus, 242, check)
      call createCurrent(P_muMinus, P_muPlus, P_Hh, 199, check)
      call createCurrent(P_ghZAnti, P_WMinus, P_ghWp, 638, check)
      call createCurrent(P_A, P_A, P_A, P_A, 1570, check)
      call createCurrent(P_Hh, P_WMinus, P_Hl, P_WPlus, 434, check)
      call createCurrent(P_t, P_WMinus, P_bAnti, 241, check)
      call createCurrent(P_Hl, P_GPlus, P_GMinus, P_Hh, 801, check)
      call createCurrent(P_Hl, P_c, P_cAnti, 636, check)
      call createCurrent(P_G0, P_G0, P_Hh, 650, check)
      call createCurrent(P_GPlus, P_WMinus, P_A, P_Hl, 47, check)
      call createCurrent(P_b, P_bAnti, P_Hl, 826, check)
      call createCurrent(P_A, P_GMinus, P_WPlus, P_Hl, 774, check)
      call createCurrent(P_WMinus, P_ghWp, P_ghAAnti, 824, check)
      call createCurrent(P_Hh, P_GMinus, P_WPlus, P_A, 264, check)
      call createCurrent(P_Z, P_WPlus, P_GMinus, P_G0, 1259, check)
      call createCurrent(P_g, P_g, P_WMinus, P_WPlus, 1601, check)
      call createCurrent(P_A, P_GPlus, P_GMinus, 1362, check)
      call createCurrent(P_WPlus, P_Z, P_GMinus, 780, check)
      call createCurrent(P_bAnti, P_A, P_b, 1045, check)
      call createCurrent(P_A, P_A, P_A, P_Z, 1628, check)
      call createCurrent(P_G0, P_t, P_tAnti, 1144, check)
      call createCurrent(P_cAnti, P_c, P_G0, 778, check)
      call createCurrent(P_tAnti, P_Hl, P_t, 385, check)
      call createCurrent(P_ghZAnti, P_ghZ, P_Hh, 304, check)
      call createCurrent(P_bAnti, P_g, P_b, 187, check)
      call createCurrent(P_GMinus, P_Hl, P_GPlus, 1133, check)
      call createCurrent(P_Hh, P_g, P_Hl, P_g, 1552, check)
      call createCurrent(P_Hh, P_GPlus, P_Hl, P_GMinus, 770, check)
      call createCurrent(P_GMinus, P_A, P_GPlus, 591, check)
      call createCurrent(P_GMinus, P_A, P_GPlus, P_A, 979, check)
      call createCurrent(P_WPlus, P_Hh, P_Hh, P_WMinus, 665, check)
      call createCurrent(P_Hh, P_ghWpAnti, P_ghWp, 524, check)
      call createCurrent(P_ghWpAnti, P_WPlus, P_ghA, 676, check)
      call createCurrent(P_GMinus, P_GPlus, P_Hl, 1227, check)
      call createCurrent(P_ghWmAnti, P_Hl, P_ghWm, 310, check)
      call createCurrent(P_g, P_uAnti, P_u, 1257, check)
      call createCurrent(P_G0, P_Hl, P_A, 1503, check)
      call createCurrent(P_muMinus, P_G0, P_muPlus, 1096, check)
      call createCurrent(P_A, P_WMinus, P_GPlus, P_Hl, 1264, check)
      call createCurrent(P_nu_mu, P_GMinus, P_muPlus, 762, check)
      call createCurrent(P_ghWp, P_ghAAnti, P_WMinus, 1258, check)
      call createCurrent(P_G0, P_Z, P_GMinus, P_WPlus, 61, check)
      call createCurrent(P_tauMinus, P_Hl, P_tauPlus, 548, check)
      call createCurrent(P_ghZAnti, P_ghWm, P_WPlus, 932, check)
      call createCurrent(P_Hh, P_bAnti, P_b, 1260, check)
      call createCurrent(P_ghWmAnti, P_Z, P_ghWm, 1375, check)
      call createCurrent(P_tauPlus, P_tauMinus, P_G0, 273, check)
      call createCurrent(P_Hh, P_Z, P_Z, P_Hh, 970, check)
      call createCurrent(P_Hh, P_Hh, P_Z, P_A, 1525, check)
      call createCurrent(P_g, P_Z, P_A, P_g, 1620, check)
      call createCurrent(P_muPlus, P_Z, P_muMinus, 734, check)
      call createCurrent(P_GMinus, P_Z, P_Z, P_GPlus, 380, check)
      call createCurrent(P_GPlus, P_ghWpAnti, P_ghZ, 1261, check)
      call createCurrent(P_A, P_A, P_Z, P_A, 1643, check)
      call createCurrent(P_Hl, P_GMinus, P_WPlus, P_Z, 383, check)
      call createCurrent(P_d, P_Hh, P_dAnti, 1276, check)
      call createCurrent(P_GMinus, P_Hh, P_GPlus, P_Hh, 28, check)
      call createCurrent(P_ghWpAnti, P_ghWp, P_Hh, 122, check)
      call createCurrent(P_Hh, P_Hh, P_g, P_g, 1578, check)
      call createCurrent(P_Hl, P_Hl, P_Hl, P_Hl, 115, check)
      call createCurrent(P_GPlus, P_Hh, P_GMinus, P_Hl, 95, check)
      call createCurrent(P_A, P_Hl, P_Hl, P_Z, 1396, check)
      call createCurrent(P_Z, P_cAnti, P_c, 325, check)
      call createCurrent(P_Hl, P_ghZ, P_ghZAnti, 997, check)
      call createCurrent(P_muPlus, P_G0, P_muMinus, 156, check)
      call createCurrent(P_nu_eAnti, P_A, P_nu_e, 1395, check)
      call createCurrent(P_nu_tauAnti, P_WPlus, P_tauMinus, 1213, check)
      call createCurrent(P_nu_tau, P_tauPlus, P_GMinus, 679, check)
      call createCurrent(P_A, P_A, P_Hl, P_Hh, 1669, check)
      call createCurrent(P_g, P_A, P_g, P_A, 1639, check)
      call createCurrent(P_Z, P_Z, P_Hh, 319, check)
      call createCurrent(P_s, P_cAnti, P_GPlus, 1230, check)
      call createCurrent(P_cAnti, P_c, P_A, 1119, check)
      call createCurrent(P_WMinus, P_Hl, P_A, P_GPlus, 699, check)
      call createCurrent(P_WPlus, P_GMinus, P_Z, P_Hh, 150, check)
      call createCurrent(P_Hh, P_WMinus, P_Hh, P_WPlus, 126, check)
      call createCurrent(P_ghWm, P_WPlus, P_ghAAnti, 98, check)
      call createCurrent(P_A, P_WMinus, P_GPlus, 693, check)
      call createCurrent(P_Hl, P_Hl, P_A, P_A, 1546, check)
      call createCurrent(P_WMinus, P_ghA, P_ghWmAnti, 670, check)
      call createCurrent(P_tauMinus, P_G0, P_tauPlus, 1327, check)
      call createCurrent(P_G0, P_ghWpAnti, P_ghWp, 1262, check)
      call createCurrent(P_GMinus, P_nu_e, P_ePlus, 904, check)
      call createCurrent(P_Z, P_Z, P_Hh, P_Hl, 944, check)
      call createCurrent(P_Hl, P_Hh, P_Hl, P_Hh, 476, check)
      call createCurrent(P_WMinus, P_ePlus, P_nu_e, 587, check)
      call createCurrent(P_WPlus, P_Hh, P_WMinus, P_Hh, 1020, check)
      call createCurrent(P_Z, P_G0, P_Hh, 1274, check)
      call createCurrent(P_Hh, P_GPlus, P_Hh, P_GMinus, 349, check)
      call createCurrent(P_Hl, P_WMinus, P_Hh, P_WPlus, 448, check)
      call createCurrent(P_cAnti, P_GPlus, P_s, 1272, check)
      call createCurrent(P_uAnti, P_u, P_A, 935, check)
      call createCurrent(P_tAnti, P_G0, P_t, 630, check)
      call createCurrent(P_Hl, P_ghWmAnti, P_ghWm, 215, check)
      call createCurrent(P_muPlus, P_nu_mu, P_GMinus, 1277, check)
      call createCurrent(P_GPlus, P_WMinus, P_Hl, P_A, 1150, check)
      call createCurrent(P_Z, P_nu_eAnti, P_nu_e, 307, check)
      call createCurrent(P_WMinus, P_WPlus, P_Hh, P_Hh, 309, check)
      call createCurrent(P_ghZAnti, P_ghWp, P_WMinus, 1041, check)
      call createCurrent(P_tAnti, P_Z, P_t, 179, check)
      call createCurrent(P_Hh, P_Hh, 1417, check)
      call createCurrent(P_WMinus, P_u, P_dAnti, 26, check)
      call createCurrent(P_G0, P_Z, P_Z, P_G0, 311, check)
      call createCurrent(P_Hh, P_muMinus, P_muPlus, 230, check)
      call createCurrent(P_WMinus, P_Hh, P_Z, P_GPlus, 363, check)
      call createCurrent(P_ghWm, P_ghWmAnti, P_Hh, 116, check)
      call createCurrent(P_Hl, P_A, P_GPlus, P_WMinus, 422, check)
      call createCurrent(P_tauMinus, P_tauPlus, P_Z, 45, check)
      call createCurrent(P_G0, P_WPlus, P_WMinus, P_G0, 232, check)
      call createCurrent(P_Hh, P_Hl, P_GMinus, P_GPlus, 976, check)
      call createCurrent(P_b, P_bAnti, P_g, 387, check)
      call createCurrent(P_Z, P_WMinus, P_Hh, P_GPlus, 689, check)
      call createCurrent(P_nu_mu, P_WMinus, P_muPlus, 859, check)
      call createCurrent(P_tauMinus, P_nu_tauAnti, P_WPlus, 588, check)
      call createCurrent(P_A, P_A, P_WMinus, P_WPlus, 520, check)
      call createCurrent(P_G0, P_WPlus, P_GMinus, P_Z, 27, check)
      call createCurrent(P_Hh, P_Hh, P_Z, P_Z, 1013, check)
      call createCurrent(P_Hl, P_WPlus, P_Hh, P_WMinus, 127, check)
      call createCurrent(P_g, P_A, P_A, P_g, 1638, check)
      call createCurrent(P_sAnti, P_Z, P_s, 275, check)
      call createCurrent(P_Hl, P_G0, P_Hh, P_G0, 301, check)
      call createCurrent(P_Hh, P_GMinus, P_GPlus, 376, check)
      call createCurrent(P_G0, P_g, P_g, P_G0, 1663, check)
      call createCurrent(P_g, P_WPlus, P_WMinus, P_g, 1608, check)
      call createCurrent(P_Z, P_muMinus, P_muPlus, 978, check)
      call createCurrent(P_WPlus, P_Z, P_Hh, P_GMinus, 1052, check)
      call createCurrent(P_Hh, P_A, P_WPlus, P_GMinus, 21, check)
      call createCurrent(P_b, P_tAnti, P_GPlus, 551, check)
      call createCurrent(P_GMinus, P_WPlus, P_G0, P_A, 1348, check)
      call createCurrent(P_dAnti, P_A, P_d, 1200, check)
      call createCurrent(P_Hl, P_G0, P_A, 1418, check)
      call createCurrent(P_GPlus, P_WMinus, 1517, check)
      call createCurrent(P_Z, P_tAnti, P_t, 584, check)
      call createCurrent(P_tauMinus, P_GPlus, P_nu_tauAnti, 236, check)
      call createCurrent(P_Z, P_G0, P_WPlus, P_GMinus, 1207, check)
      call createCurrent(P_A, P_A, P_Z, P_Z, 1625, check)
      call createCurrent(P_GMinus, P_WPlus, P_Z, 103, check)
      call createCurrent(P_Hl, P_GMinus, P_Z, P_WPlus, 745, check)
      call createCurrent(P_A, P_Hl, P_WMinus, P_GPlus, 496, check)
      call createCurrent(P_s, P_sAnti, 1481, check)
      call createCurrent(P_WMinus, P_GPlus, P_Hl, 17, check)
      call createCurrent(P_u, P_dAnti, P_GMinus, 662, check)
      call createCurrent(P_GMinus, P_GPlus, P_Z, P_Z, 910, check)
      call createCurrent(P_Hh, P_WPlus, P_GMinus, 546, check)
      call createCurrent(P_G0, P_G0, P_Hh, P_Hh, 314, check)
      call createCurrent(P_g, P_G0, P_g, P_G0, 1636, check)
      call createCurrent(P_nu_muAnti, P_nu_mu, P_Z, 692, check)
      call createCurrent(P_Hl, P_A, P_GMinus, P_WPlus, 556, check)
      call createCurrent(P_Hl, P_Z, P_GMinus, P_WPlus, 788, check)
      call createCurrent(P_Hh, P_ghWm, P_ghWmAnti, 1190, check)
      call createCurrent(P_sAnti, P_c, P_WMinus, 803, check)
      call createCurrent(P_WPlus, P_Hl, P_Hh, P_WMinus, 1311, check)
      call createCurrent(P_bAnti, P_t, P_GMinus, 168, check)
      call createCurrent(P_c, P_cAnti, P_g, 707, check)
      call createCurrent(P_GPlus, P_Hl, P_WMinus, 1291, check)
      call createCurrent(P_WPlus, P_Hh, P_Z, P_GMinus, 102, check)
      call createCurrent(P_Hl, P_Hh, P_G0, P_G0, 425, check)
      call createCurrent(P_G0, P_G0, 1419, check)
      call createCurrent(P_A, P_Hh, P_WMinus, P_GPlus, 1142, check)
      call createCurrent(P_WMinus, P_bAnti, P_t, 14, check)
      call createCurrent(P_GPlus, P_WMinus, P_Z, P_G0, 876, check)
      call createCurrent(P_GMinus, P_Z, P_Hh, P_WPlus, 493, check)
      call createCurrent(P_G0, P_GMinus, P_WPlus, 766, check)
      call createCurrent(P_WMinus, P_WPlus, P_A, 1288, check)
      call createCurrent(P_Z, P_G0, P_GMinus, P_WPlus, 1211, check)
      call createCurrent(P_A, P_GPlus, P_Hh, P_WMinus, 427, check)
      call createCurrent(P_Hh, P_GMinus, P_GPlus, P_Hl, 292, check)
      call createCurrent(P_GMinus, P_WPlus, P_Hh, P_A, 479, check)
      call createCurrent(P_sAnti, P_GMinus, P_c, 1194, check)
      call createCurrent(P_Hl, P_sAnti, P_s, 483, check)
      call createCurrent(P_GPlus, P_cAnti, P_s, 124, check)
      call createCurrent(P_ghWmAnti, P_Hh, P_ghWm, 1138, check)
      call createCurrent(P_WMinus, P_Hl, P_GPlus, P_A, 357, check)
      call createCurrent(P_Hh, P_sAnti, P_s, 828, check)
      call createCurrent(P_ghWpAnti, P_ghA, P_GPlus, 320, check)
      call createCurrent(P_GPlus, P_g, P_g, P_GMinus, 1614, check)
      call createCurrent(P_nu_eAnti, P_GPlus, P_eMinus, 328, check)
      call createCurrent(P_Hl, P_Hh, P_Z, P_A, 1505, check)
      call createCurrent(P_Z, P_WMinus, P_WPlus, P_A, 189, check)
      call createCurrent(P_GPlus, P_ghWm, P_ghZAnti, 753, check)
      call createCurrent(P_GPlus, P_GMinus, P_A, 1088, check)
      call createCurrent(P_Hl, P_Hl, P_GMinus, P_GPlus, 107, check)
      call createCurrent(P_tauMinus, P_Hh, P_tauPlus, 414, check)
      call createCurrent(P_Hl, P_A, P_Z, P_Hh, 1475, check)
      call createCurrent(P_Z, P_Z, P_A, P_Z, 1671, check)
      call createCurrent(P_g, P_bAnti, P_b, 43, check)
      call createCurrent(P_ghA, P_WMinus, P_ghWmAnti, 1027, check)
      call createCurrent(P_WMinus, P_muPlus, P_nu_mu, 892, check)
      call createCurrent(P_u, P_GMinus, P_dAnti, 1336, check)
      call createCurrent(P_Hl, P_Hl, P_Hh, 1313, check)
      call createCurrent(P_ghA, P_ghWmAnti, P_GMinus, 302, check)
      call createCurrent(P_GMinus, P_Z, P_WPlus, P_Hh, 516, check)
      call createCurrent(P_A, P_GPlus, P_G0, P_WMinus, 324, check)
      call createCurrent(P_WMinus, P_GPlus, P_A, P_G0, 499, check)
      call createCurrent(P_WMinus, P_sAnti, P_c, 504, check)
      call createCurrent(P_ghA, P_ghWpAnti, P_WPlus, 1019, check)
      call createCurrent(P_GMinus, P_ghWmAnti, P_ghA, 875, check)
      call createCurrent(P_bAnti, P_b, P_A, 582, check)
      call createCurrent(P_WPlus, P_G0, P_WMinus, P_G0, 576, check)
      call createCurrent(P_G0, P_G0, P_GPlus, P_GMinus, 379, check)
      call createCurrent(P_WPlus, P_WMinus, P_Hh, P_Hl, 279, check)
      call createCurrent(P_GMinus, P_muPlus, P_nu_mu, 1271, check)
      call createCurrent(P_Z, P_WPlus, P_Hh, P_GMinus, 696, check)
      call createCurrent(P_GMinus, P_A, P_A, P_GPlus, 860, check)
      call createCurrent(P_G0, P_muPlus, P_muMinus, 748, check)
      call createCurrent(P_GPlus, P_A, P_WMinus, 533, check)
      call createCurrent(P_ghWmAnti, P_ghZ, P_WMinus, 83, check)
      call createCurrent(P_b, P_GPlus, P_tAnti, 1294, check)
      call createCurrent(P_GMinus, P_GPlus, P_GMinus, P_GPlus, 233, check)
      call createCurrent(P_muPlus, P_muMinus, P_A, 1073, check)
      call createCurrent(P_Z, P_Hl, P_A, P_Hh, 1480, check)
      call createCurrent(P_WMinus, P_nu_tau, P_tauPlus, 1203, check)
      call createCurrent(P_WMinus, P_A, P_Z, P_WPlus, 388, check)
      call createCurrent(P_b, P_WPlus, P_tAnti, 338, check)
      call createCurrent(P_Hh, P_Z, P_WMinus, P_GPlus, 1135, check)
      call createCurrent(P_Z, P_Hh, P_Z, P_Hl, 775, check)
      call createCurrent(P_b, P_bAnti, 1425, check)
      call createCurrent(P_G0, P_GPlus, P_A, P_WMinus, 299, check)
      call createCurrent(P_ghZ, P_ghZAnti, P_Hh, 1156, check)
      call createCurrent(P_Z, P_G0, 1402, check)
      call createCurrent(P_A, P_nu_tauAnti, P_nu_tau, 1522, check)
      call createCurrent(P_tauMinus, P_A, P_tauPlus, 87, check)
      call createCurrent(P_GMinus, P_WMinus, P_WPlus, P_GPlus, 400, check)
      call createCurrent(P_ghWp, P_ghWpAnti, P_Hl, 995, check)
      call createCurrent(P_GPlus, P_Z, P_A, P_GMinus, 1037, check)
      call createCurrent(P_uAnti, P_g, P_u, 643, check)
      call createCurrent(P_Hh, P_Hl, P_A, P_A, 1611, check)
      call createCurrent(P_Hh, P_Z, P_Z, 685, check)
      call createCurrent(P_GMinus, P_GPlus, P_G0, P_G0, 30, check)
      call createCurrent(P_WPlus, P_G0, P_A, P_GMinus, 1339, check)
      call createCurrent(P_G0, P_A, 1526, check)
      call createCurrent(P_Hl, P_uAnti, P_u, 423, check)
      call createCurrent(P_GMinus, P_g, P_GPlus, P_g, 1609, check)
      call createCurrent(P_ePlus, P_A, P_eMinus, 1280, check)
      call createCurrent(P_g, P_GMinus, P_g, P_GPlus, 1559, check)
      call createCurrent(P_ghWmAnti, P_ghWm, P_Z, 209, check)
      call createCurrent(P_uAnti, P_Hl, P_u, 390, check)
      call createCurrent(P_tauPlus, P_nu_tau, P_WMinus, 72, check)
      call createCurrent(P_GPlus, P_Z, P_GMinus, P_Z, 1319, check)
      call createCurrent(P_GPlus, P_A, P_Hh, P_WMinus, 1010, check)
      call createCurrent(P_GPlus, P_WMinus, P_G0, P_A, 577, check)
      call createCurrent(P_dAnti, P_d, P_G0, 482, check)
      call createCurrent(P_G0, P_cAnti, P_c, 853, check)
      call createCurrent(P_WPlus, P_A, P_GMinus, P_G0, 830, check)
      call createCurrent(P_A, P_Hh, P_A, P_Hl, 1564, check)
      call createCurrent(P_c, P_G0, P_cAnti, 930, check)
      call createCurrent(P_nu_mu, P_muPlus, P_GMinus, 850, check)
      call createCurrent(P_Hl, P_WMinus, P_Z, P_GPlus, 722, check)
      call createCurrent(P_muMinus, P_muPlus, P_G0, 1278, check)
      call createCurrent(P_Hh, P_eMinus, P_ePlus, 50, check)
      call createCurrent(P_nu_muAnti, P_muMinus, P_GPlus, 85, check)
      call createCurrent(P_GMinus, P_A, P_WPlus, P_Hh, 1341, check)
      call createCurrent(P_Hh, P_A, P_A, 1572, check)
      call createCurrent(P_bAnti, P_Hh, P_b, 481, check)
      call createCurrent(P_A, P_A, P_Hh, 1658, check)
      call createCurrent(P_G0, P_G0, P_A, P_A, 1626, check)
      call createCurrent(P_uAnti, P_d, P_WPlus, 331, check)
      call createCurrent(P_A, P_Z, P_g, P_g, 1598, check)
      call createCurrent(P_A, P_GMinus, P_Z, P_GPlus, 1206, check)
      call createCurrent(P_GMinus, P_WPlus, P_WMinus, P_GPlus, 93, check)
      call createCurrent(P_WMinus, P_A, P_Hh, P_GPlus, 867, check)
      call createCurrent(P_g, P_g, P_g, P_A, 1631, check)
      call createCurrent(P_Hl, P_GPlus, P_WMinus, 1072, check)
      call createCurrent(P_A, P_GMinus, P_GPlus, 446, check)
      call createCurrent(P_A, P_dAnti, P_d, 628, check)
      call createCurrent(P_Hl, P_Z, P_Z, P_Hl, 629, check)
      call createCurrent(P_sAnti, P_s, 1483, check)
      call createCurrent(P_c, P_sAnti, P_GMinus, 1246, check)
      call createCurrent(P_Hl, P_Hl, P_G0, P_G0, 725, check)
      call createCurrent(P_GPlus, P_GMinus, P_Hl, 58, check)
      call createCurrent(P_ghWpAnti, P_GPlus, P_ghA, 634, check)
      call createCurrent(P_cAnti, P_c, P_Hl, 1183, check)
      call createCurrent(P_GPlus, P_GPlus, P_GMinus, P_GMinus, 642, check)
      call createCurrent(P_WMinus, P_Z, P_Hh, P_GPlus, 471, check)
      call createCurrent(P_Z, P_Z, P_G0, P_G0, 869, check)
      call createCurrent(P_A, P_Hl, P_Z, 1387, check)
      call createCurrent(P_d, P_dAnti, P_Hl, 399, check)
      call createCurrent(P_Z, P_Z, P_Hl, 288, check)
      call createCurrent(P_Hh, P_ghZ, P_ghZAnti, 1268, check)
      call createCurrent(P_WPlus, P_GMinus, P_GPlus, P_WMinus, 952, check)
      call createCurrent(P_u, P_uAnti, P_G0, 454, check)
      call createCurrent(P_Hh, P_GMinus, P_Hl, P_GPlus, 489, check)
      call createCurrent(P_dAnti, P_Hl, P_d, 901, check)
      call createCurrent(P_t, P_G0, P_tAnti, 870, check)
      call createCurrent(P_g, P_Hl, P_g, 1540, check)
      call createCurrent(P_GPlus, P_WMinus, P_A, P_Hh, 963, check)
      call createCurrent(P_GMinus, P_WPlus, P_Hh, P_Z, 332, check)
      call createCurrent(P_A, P_GMinus, P_WPlus, P_Hh, 306, check)
      call createCurrent(P_A, P_nu_tau, P_nu_tauAnti, 1404, check)
      call createCurrent(P_WPlus, P_Z, P_WMinus, 194, check)
      call createCurrent(P_g, P_Hh, P_Hl, P_g, 1622, check)
      call createCurrent(P_WPlus, P_tauMinus, P_nu_tauAnti, 261, check)
      call createCurrent(P_Hl, P_g, P_g, P_Hh, 1651, check)
      call createCurrent(P_ghZAnti, P_WPlus, P_ghWm, 760, check)
      call createCurrent(P_A, P_Hl, P_G0, 1455, check)
      call createCurrent(P_cAnti, P_c, P_Z, 1322, check)
      call createCurrent(P_Hl, P_Hl, P_g, P_g, 1664, check)
      call createCurrent(P_GPlus, P_Hl, P_WMinus, P_A, 1243, check)
      call createCurrent(P_GMinus, P_Hl, P_WPlus, P_A, 590, check)
      call createCurrent(P_GPlus, P_WMinus, P_Z, 347, check)
      call createCurrent(P_Z, P_WPlus, P_Hl, P_GMinus, 1178, check)
      call createCurrent(P_Z, P_Hl, P_A, P_Hl, 1393, check)
      call createCurrent(P_Z, P_GMinus, P_WPlus, P_Hh, 2, check)
      call createCurrent(P_WPlus, P_Hl, P_GMinus, P_A, 971, check)
      call createCurrent(P_GMinus, P_GPlus, P_A, P_Z, 262, check)
      call createCurrent(P_t, P_GMinus, P_bAnti, 1338, check)
      call createCurrent(P_A, P_A, P_Hl, 1627, check)
      call createCurrent(P_ghZ, P_WMinus, P_ghWmAnti, 1219, check)
      call createCurrent(P_A, P_WMinus, P_GPlus, P_Hh, 779, check)
      call createCurrent(P_Z, P_Hl, P_Hh, P_Z, 188, check)
      call createCurrent(P_Hh, P_WMinus, P_GPlus, 923, check)
      call createCurrent(P_G0, P_WPlus, P_A, P_GMinus, 76, check)
      call createCurrent(P_Hl, P_Hh, 1470, check)
      call createCurrent(P_ghWp, P_WMinus, P_ghZAnti, 743, check)
      call createCurrent(P_ghWm, P_ghZAnti, P_GPlus, 344, check)
      call createCurrent(P_muMinus, P_GPlus, P_nu_muAnti, 1040, check)
      call createCurrent(P_u, P_A, P_uAnti, 846, check)
      call createCurrent(P_ghZ, P_ghWmAnti, P_WMinus, 1126, check)
      call createCurrent(P_GMinus, P_Hh, P_Z, P_WPlus, 833, check)
      call createCurrent(P_WPlus, P_Z, P_GMinus, P_Hh, 456, check)
      call createCurrent(P_A, P_u, P_uAnti, 509, check)
      call createCurrent(P_Hl, P_Hh, P_Hh, P_Hh, 759, check)
      call createCurrent(P_ghWpAnti, P_ghZ, P_WPlus, 183, check)
      call createCurrent(P_WPlus, P_Hl, P_WMinus, P_Hh, 1310, check)
      call createCurrent(P_ghZ, P_ghZAnti, P_Hl, 1196, check)
      call createCurrent(P_GMinus, P_A, P_Z, P_GPlus, 63, check)
      call createCurrent(P_Hl, P_WPlus, P_WMinus, P_Hl, 909, check)
      call createCurrent(P_ghA, P_ghWpAnti, P_GPlus, 872, check)
      call createCurrent(P_Z, P_GPlus, P_GMinus, 436, check)
      call createCurrent(P_G0, P_ghWm, P_ghWmAnti, 1015, check)
      call createCurrent(P_G0, P_A, P_WPlus, P_GMinus, 1005, check)
      call createCurrent(P_GMinus, P_Hh, P_GPlus, P_Hl, 207, check)
      call createCurrent(P_dAnti, P_GMinus, P_u, 24, check)
      call createCurrent(P_bAnti, P_Hl, P_b, 407, check)
      call createCurrent(P_WPlus, P_GMinus, P_Z, P_G0, 441, check)
      call createCurrent(P_ghWp, P_ghWpAnti, P_G0, 1124, check)
      call createCurrent(P_GMinus, P_Hh, P_WPlus, P_A, 473, check)
      call createCurrent(P_GPlus, P_Hh, P_GMinus, P_Hh, 240, check)
      call createCurrent(P_A, P_GPlus, P_GMinus, P_Z, 468, check)
      call createCurrent(P_GMinus, P_GPlus, P_WPlus, P_WMinus, 631, check)
      call createCurrent(P_muMinus, P_WPlus, P_nu_muAnti, 877, check)
      call createCurrent(P_g, P_Z, P_g, P_A, 1562, check)
      call createCurrent(P_Z, P_Hl, P_Hl, P_A, 1498, check)
      call createCurrent(P_WPlus, P_A, P_GMinus, P_Hl, 893, check)
      call createCurrent(P_WMinus, P_Z, P_WPlus, P_A, 849, check)
      call createCurrent(P_G0, P_muMinus, P_muPlus, 94, check)
      call createCurrent(P_Hh, P_ePlus, P_eMinus, 49, check)
      call createCurrent(P_nu_mu, P_muPlus, P_WMinus, 583, check)
      call createCurrent(P_WMinus, P_WPlus, P_A, P_Z, 23, check)
      call createCurrent(P_Hh, P_A, P_Hl, P_Z, 1394, check)
      call createCurrent(P_WPlus, P_Hh, P_GMinus, P_A, 112, check)
      call createCurrent(P_WPlus, P_GMinus, P_Z, P_Hl, 615, check)
      call createCurrent(P_GPlus, P_G0, P_G0, P_GMinus, 1028, check)
      call createCurrent(P_Z, P_Z, P_A, P_A, 1670, check)
      call createCurrent(P_Hh, P_tauPlus, P_tauMinus, 1360, check)
      call createCurrent(P_nu_muAnti, P_muMinus, P_WPlus, 688, check)
      call createCurrent(P_Z, P_Hl, P_GMinus, P_WPlus, 374, check)
      call createCurrent(P_WPlus, P_WMinus, P_A, P_A, 1352, check)
      call createCurrent(P_tauMinus, P_tauPlus, P_A, 1263, check)
      call createCurrent(P_Hh, P_G0, P_A, 1491, check)
      call createCurrent(P_A, P_A, P_WPlus, P_WMinus, 162, check)
      call createCurrent(P_Z, P_GMinus, P_GPlus, P_A, 1014, check)
      call createCurrent(P_g, P_g, P_G0, P_G0, 1645, check)
      call createCurrent(P_Z, P_Hh, P_Hl, P_A, 1422, check)
      call createCurrent(P_ghWp, P_G0, P_ghWpAnti, 580, check)
      call createCurrent(P_GMinus, P_Z, P_GPlus, 553, check)
      call createCurrent(P_GPlus, P_muMinus, P_nu_muAnti, 907, check)
      call createCurrent(P_g, P_g, P_Z, P_g, 1532, check)
      call createCurrent(P_muMinus, P_A, P_muPlus, 268, check)
      call createCurrent(P_muPlus, P_WMinus, P_nu_mu, 1113, check)
      call createCurrent(P_Z, P_GPlus, P_Hh, P_WMinus, 1091, check)
      call createCurrent(P_Hh, P_Hl, P_Z, P_Z, 132, check)
      call createCurrent(P_Z, P_GMinus, P_GPlus, 1222, check)
      call createCurrent(P_WPlus, P_WMinus, P_Z, P_Z, 48, check)
      call createCurrent(P_GPlus, P_GMinus, P_Hl, P_Hh, 1114, check)
      call createCurrent(P_ePlus, P_WMinus, P_nu_e, 360, check)
      call createCurrent(P_uAnti, P_Hh, P_u, 1233, check)
      call createCurrent(P_d, P_dAnti, P_g, 382, check)
      call createCurrent(P_g, P_A, P_g, P_g, 1656, check)
      call createCurrent(P_WMinus, P_WPlus, P_Hh, P_Hl, 776, check)
      call createCurrent(P_A, P_WMinus, P_WPlus, P_A, 807, check)
      call createCurrent(P_GPlus, P_GMinus, P_GMinus, P_GPlus, 782, check)
      call createCurrent(P_WPlus, P_Z, P_Z, P_WMinus, 921, check)
      call createCurrent(P_ghWmAnti, P_GMinus, P_ghA, 1302, check)
      call createCurrent(P_GPlus, P_WPlus, P_WMinus, P_GMinus, 377, check)
      call createCurrent(P_g, P_g, P_WPlus, P_WMinus, 1567, check)
      call createCurrent(P_g, P_A, P_Z, P_g, 1624, check)
      call createCurrent(P_ePlus, P_eMinus, P_Z, 231, check)
      call createCurrent(P_ghWmAnti, P_ghWm, P_G0, 1289, check)
      call createCurrent(P_cAnti, P_Hh, P_c, 1218, check)
      call createCurrent(P_A, P_Hl, P_GPlus, P_WMinus, 364, check)
      call createCurrent(P_Hl, P_Hl, P_WMinus, P_WPlus, 799, check)
      call createCurrent(P_ghWp, P_Hl, P_ghWpAnti, 1169, check)
      call createCurrent(P_GPlus, P_GMinus, 1427, check)
      call createCurrent(P_c, P_g, P_cAnti, 1244, check)
      call createCurrent(P_c, P_cAnti, P_Z, 389, check)
      call createCurrent(P_G0, P_WPlus, P_GMinus, 204, check)
      call createCurrent(P_GPlus, P_Hl, P_GMinus, P_Hh, 1335, check)
      call createCurrent(P_GPlus, P_GMinus, P_WMinus, P_WPlus, 886, check)
      call createCurrent(P_Hl, P_Hl, P_Hl, 1351, check)
      call createCurrent(P_GMinus, P_Hl, P_Hh, P_GPlus, 1365, check)
      call createCurrent(P_nu_tau, P_A, P_nu_tauAnti, 1431, check)
      call createCurrent(P_dAnti, P_Z, P_d, 223, check)
      call createCurrent(P_GPlus, P_G0, P_WMinus, P_A, 1312, check)
      call createCurrent(P_Z, P_Hh, P_A, P_Hl, 1472, check)
      call createCurrent(P_A, P_Hl, P_Z, P_Hl, 1408, check)
      call createCurrent(P_A, P_GMinus, P_WPlus, 736, check)
      call createCurrent(P_A, P_WPlus, P_GMinus, P_G0, 936, check)
      call createCurrent(P_Z, P_GPlus, P_GMinus, P_Z, 52, check)
      call createCurrent(P_sAnti, P_WMinus, P_c, 568, check)
      call createCurrent(P_uAnti, P_u, P_G0, 949, check)
      call createCurrent(P_GPlus, P_tAnti, P_b, 620, check)
      call createCurrent(P_GMinus, P_Hl, P_GPlus, P_Hl, 635, check)
      call createCurrent(P_WMinus, P_GPlus, P_Z, P_Hl, 1361, check)
      call createCurrent(P_Hh, P_GPlus, P_A, P_WMinus, 340, check)
      call createCurrent(P_ghZ, P_WPlus, P_ghWpAnti, 925, check)
      call createCurrent(P_WMinus, P_GPlus, P_Hh, P_A, 601, check)
      call createCurrent(P_G0, P_Hh, P_Z, 413, check)
      call createCurrent(P_Z, P_GPlus, P_G0, P_WMinus, 1229, check)
      call createCurrent(P_GMinus, P_dAnti, P_u, 465, check)
      call createCurrent(P_Hl, P_b, P_bAnti, 791, check)
      call createCurrent(P_tAnti, P_t, P_Hl, 559, check)
      call createCurrent(P_G0, P_G0, P_Hh, P_Hl, 59, check)
      call createCurrent(P_Hh, P_A, P_Z, P_Hh, 1461, check)
      call createCurrent(P_Hl, P_A, P_Hh, P_A, 1565, check)
      call createCurrent(P_GPlus, P_Hh, P_Z, P_WMinus, 1270, check)
      call createCurrent(P_g, P_g, P_A, P_Z, 1673, check)
      call createCurrent(P_A, P_A, 1513, check)
      call createCurrent(P_Hh, P_WMinus, P_Z, P_GPlus, 281, check)
      call createCurrent(P_WMinus, P_Z, P_Z, P_WPlus, 78, check)
      call createCurrent(P_Hl, P_Hh, P_A, P_Z, 1421, check)
      call createCurrent(P_WPlus, P_g, P_g, P_WMinus, 1537, check)
      call createCurrent(P_WPlus, P_WMinus, P_Z, 1323, check)
      call createCurrent(P_Hh, P_A, P_Z, P_Hl, 1520, check)
      call createCurrent(P_WPlus, P_muMinus, P_nu_muAnti, 563, check)
      call createCurrent(P_WMinus, P_GMinus, P_WPlus, P_GPlus, 989, check)
      call createCurrent(P_Hh, P_A, P_GPlus, P_WMinus, 303, check)
      call createCurrent(P_ghWp, P_ghWpAnti, P_Hh, 1208, check)
      call createCurrent(P_A, P_A, P_g, P_g, 1667, check)
      call createCurrent(P_Hh, P_GMinus, P_WPlus, P_Z, 51, check)
      call createCurrent(P_GMinus, P_GPlus, P_A, 1099, check)
      call createCurrent(P_A, P_G0, P_G0, P_A, 1555, check)
      call createCurrent(P_b, P_bAnti, P_Z, 70, check)
      call createCurrent(P_Z, P_Z, 1490, check)
      call createCurrent(P_Hl, P_tAnti, P_t, 254, check)
      call createCurrent(P_A, P_eMinus, P_ePlus, 765, check)
      call createCurrent(P_g, P_g, P_Z, P_Z, 1648, check)
      call createCurrent(P_WMinus, P_A, P_WPlus, 395, check)
      call createCurrent(P_WMinus, P_A, P_WPlus, P_A, 523, check)
      call createCurrent(P_Hh, P_Z, P_WPlus, P_GMinus, 966, check)
      call createCurrent(P_WPlus, P_ghWpAnti, P_ghZ, 1354, check)
      call createCurrent(P_WPlus, P_GMinus, P_Hl, P_A, 752, check)
      call createCurrent(P_Z, P_sAnti, P_s, 1110, check)
      call createCurrent(P_A, P_ghWp, P_ghWpAnti, 529, check)
      call createCurrent(P_g, P_g, P_Hh, P_Hl, 1644, check)
      call createCurrent(P_G0, P_WMinus, P_A, P_GPlus, 69, check)
      call createCurrent(P_Hl, P_A, P_A, 1595, check)
      call createCurrent(P_Hl, P_GMinus, P_Hh, P_GPlus, 257, check)
      call createCurrent(P_ghWm, P_ghAAnti, P_WPlus, 497, check)
      call createCurrent(P_Z, P_G0, P_G0, P_Z, 740, check)
      call createCurrent(P_GPlus, P_A, P_GMinus, P_Z, 649, check)
      call createCurrent(P_Hh, P_WPlus, P_WMinus, P_Hl, 463, check)
      call createCurrent(P_Hl, P_eMinus, P_ePlus, 298, check)
      call createCurrent(P_Hh, P_tauMinus, P_tauPlus, 1100, check)
      call createCurrent(P_Z, P_GPlus, P_WMinus, 143, check)
      call createCurrent(P_WPlus, P_GMinus, P_G0, P_A, 1017, check)
      call createCurrent(P_G0, P_A, P_G0, P_A, 1580, check)
      call createCurrent(P_nu_muAnti, P_Z, P_nu_mu, 1204, check)
      call createCurrent(P_G0, P_G0, P_GMinus, P_GPlus, 879, check)
      call createCurrent(P_nu_eAnti, P_nu_e, 1460, check)
      call createCurrent(P_WPlus, P_WMinus, P_Hh, P_Hh, 222, check)
      call createCurrent(P_WMinus, P_Z, P_GPlus, P_Hl, 712, check)
      call createCurrent(P_GPlus, P_nu_eAnti, P_eMinus, 1369, check)
      call createCurrent(P_A, P_Hh, P_WPlus, P_GMinus, 581, check)
      call createCurrent(P_WMinus, P_g, P_g, P_WPlus, 1543, check)
      call createCurrent(P_WMinus, P_G0, P_GPlus, P_A, 627, check)
      call createCurrent(P_A, P_Z, P_G0, P_G0, 1514, check)
      call createCurrent(P_ghWm, P_ghWmAnti, P_A, 1143, check)
      call createCurrent(P_WMinus, P_Z, P_WPlus, P_Z, 854, check)
      call createCurrent(P_WMinus, P_Z, P_G0, P_GPlus, 596, check)
      call createCurrent(P_GMinus, P_Z, P_G0, P_WPlus, 810, check)
      call createCurrent(P_c, P_GMinus, P_sAnti, 1157, check)
      call createCurrent(P_sAnti, P_Hl, P_s, 202, check)
      call createCurrent(P_Hh, P_GPlus, P_Z, P_WMinus, 792, check)
      call createCurrent(P_WPlus, P_s, P_cAnti, 1004, check)
      call createCurrent(P_Hl, P_A, P_Hl, P_Z, 1398, check)
      call createCurrent(P_WMinus, P_WPlus, 1465, check)
      call createCurrent(P_GPlus, P_GMinus, P_Hh, 25, check)
      call createCurrent(P_GMinus, P_G0, P_WPlus, 1215, check)
      call createCurrent(P_WPlus, P_Hh, P_Hl, P_WMinus, 84, check)
      call createCurrent(P_cAnti, P_c, P_Hh, 698, check)
      call createCurrent(P_G0, P_GMinus, P_G0, P_GPlus, 973, check)
      call createCurrent(P_Z, P_g, P_g, P_g, 1618, check)
      call createCurrent(P_Z, P_A, P_A, P_Z, 1581, check)
      call createCurrent(P_d, P_dAnti, P_Hh, 438, check)
      call createCurrent(P_Hl, P_WPlus, P_GMinus, P_A, 1195, check)
      call createCurrent(P_g, P_s, P_sAnti, 286, check)
      call createCurrent(P_G0, P_GPlus, P_GMinus, P_G0, 13, check)
      call createCurrent(P_eMinus, P_G0, P_ePlus, 940, check)
      call createCurrent(P_Hl, P_Hh, P_Hl, P_Hl, 318, check)
      call createCurrent(P_G0, P_WPlus, P_G0, P_WMinus, 245, check)
      call createCurrent(P_G0, P_WMinus, P_GPlus, 244, check)
      call createCurrent(P_Z, P_Hh, P_Hl, P_Z, 11, check)
      call createCurrent(P_c, P_A, P_cAnti, 956, check)
      call createCurrent(P_ghWmAnti, P_A, P_ghWm, 1148, check)
      call createCurrent(P_GPlus, P_Z, P_G0, P_WMinus, 370, check)
      call createCurrent(P_WMinus, P_WPlus, P_Z, P_A, 1161, check)
      call createCurrent(P_tauPlus, P_Z, P_tauMinus, 1127, check)
      call createCurrent(P_GPlus, P_GMinus, P_G0, P_G0, 339, check)
      call createCurrent(P_A, P_GMinus, P_Hl, P_WPlus, 174, check)
      call createCurrent(P_c, P_Hh, P_cAnti, 1029, check)
      call createCurrent(P_A, P_G0, P_GPlus, P_WMinus, 644, check)
      call createCurrent(P_Z, P_WMinus, P_A, P_WPlus, 1254, check)
      call createCurrent(P_bAnti, P_b, 1428, check)
      call createCurrent(P_A, P_GPlus, P_A, P_GMinus, 89, check)
      call createCurrent(P_ghZ, P_ghWpAnti, P_GPlus, 1083, check)
      call createCurrent(P_A, P_Hh, P_GMinus, P_WPlus, 1111, check)
      call createCurrent(P_ghA, P_ghWmAnti, P_WMinus, 248, check)
      call createCurrent(P_GMinus, P_g, P_g, P_GPlus, 1579, check)
      call createCurrent(P_c, P_Hl, P_cAnti, 1076, check)
      call createCurrent(P_Hh, P_s, P_sAnti, 90, check)
      call createCurrent(P_G0, P_A, P_Z, P_G0, 1385, check)
      call createCurrent(P_t, P_tAnti, P_Z, 1328, check)
      call createCurrent(P_GPlus, P_uAnti, P_d, 1349, check)
      call createCurrent(P_nu_tau, P_tauPlus, P_WMinus, 40, check)
      call createCurrent(P_GMinus, P_Z, P_WPlus, P_G0, 335, check)
      call createCurrent(P_t, P_bAnti, P_GMinus, 29, check)
      call createCurrent(P_Hl, P_GPlus, P_WMinus, P_A, 706, check)
      call createCurrent(P_WPlus, P_WMinus, P_A, 1049, check)
      call createCurrent(P_tAnti, P_Hh, P_t, 510, check)
      call createCurrent(P_Z, P_Hh, P_A, 1478, check)
      call createCurrent(P_A, P_muMinus, P_muPlus, 1031, check)
      call createCurrent(P_GMinus, P_WMinus, P_GPlus, P_WPlus, 1032, check)
      call createCurrent(P_GMinus, P_GPlus, P_g, P_g, 1536, check)
      call createCurrent(P_WMinus, P_Z, P_WPlus, 135, check)
      call createCurrent(P_Hh, P_A, P_A, P_Hl, 1560, check)
      call createCurrent(P_Hh, P_Hh, P_Hh, 542, check)
      call createCurrent(P_ghWpAnti, P_Hl, P_ghWp, 994, check)
      call createCurrent(P_ePlus, P_Z, P_eMinus, 396, check)
      call createCurrent(P_Z, P_ghWmAnti, P_ghWm, 526, check)
      call createCurrent(P_GMinus, P_GPlus, P_Hh, P_Hl, 719, check)
      call createCurrent(P_Hl, P_tauPlus, P_tauMinus, 485, check)
      call createCurrent(P_GMinus, P_ghZ, P_ghWmAnti, 217, check)
      call createCurrent(P_nu_e, P_Z, P_nu_eAnti, 1158, check)
      call createCurrent(P_G0, P_Hh, P_A, 1463, check)
      call createCurrent(P_GMinus, P_A, P_WPlus, P_Hl, 416, check)
      call createCurrent(P_dAnti, P_u, P_WMinus, 578, check)
      call createCurrent(P_A, P_G0, P_Hl, 1469, check)
      call createCurrent(P_uAnti, P_d, P_GPlus, 1172, check)
      call createCurrent(P_s, P_sAnti, P_G0, 426, check)
      call createCurrent(P_Hl, P_Z, P_GPlus, P_WMinus, 677, check)
      call createCurrent(P_g, P_g, P_GPlus, P_GMinus, 1534, check)
      call createCurrent(P_u, P_uAnti, P_Hl, 802, check)
      call createCurrent(P_ghZAnti, P_GPlus, P_ghWm, 1320, check)
      call createCurrent(P_Hl, P_s, P_sAnti, 37, check)
      call createCurrent(P_eMinus, P_nu_eAnti, P_GPlus, 640, check)
      call createCurrent(P_nu_muAnti, P_WPlus, P_muMinus, 1267, check)
      call createCurrent(P_WPlus, P_A, P_WMinus, P_Z, 623, check)
      call createCurrent(P_Z, P_t, P_tAnti, 1329, check)
      call createCurrent(P_nu_e, P_ePlus, P_GMinus, 754, check)
      call createCurrent(P_d, P_G0, P_dAnti, 212, check)
      call createCurrent(P_ePlus, P_eMinus, P_Hl, 671, check)
      call createCurrent(P_Hh, P_Hl, P_WMinus, P_WPlus, 1152, check)
      call createCurrent(P_Z, P_c, P_cAnti, 1067, check)
      call createCurrent(P_tAnti, P_b, P_GPlus, 60, check)
      call createCurrent(P_muPlus, P_Hl, P_muMinus, 865, check)
      call createCurrent(P_G0, P_A, P_Hl, 1405, check)
      call createCurrent(P_Z, P_Hl, P_Z, P_Hl, 977, check)
      call createCurrent(P_Z, P_GMinus, P_WPlus, P_G0, 469, check)
      call createCurrent(P_tauPlus, P_nu_tau, P_GMinus, 1224, check)
      call createCurrent(P_b, P_g, P_bAnti, 648, check)
      call createCurrent(P_WPlus, P_G0, P_G0, P_WMinus, 113, check)
      call createCurrent(P_ghA, P_GMinus, P_ghWmAnti, 175, check)
      call createCurrent(P_ePlus, P_G0, P_eMinus, 151, check)
      call createCurrent(P_WMinus, P_WPlus, P_Hh, 1139, check)
      call createCurrent(P_ghWm, P_ghWmAnti, P_Z, 988, check)
      call createCurrent(P_WMinus, P_tauPlus, P_nu_tau, 600, check)
      call createCurrent(P_WPlus, P_nu_tauAnti, P_tauMinus, 153, check)
      call createCurrent(P_ePlus, P_GMinus, P_nu_e, 1058, check)
      call createCurrent(P_Hl, P_Hl, P_WPlus, P_WMinus, 840, check)
      call createCurrent(P_ghWmAnti, P_GMinus, P_ghZ, 613, check)
      call createCurrent(P_Hl, P_g, P_g, P_Hl, 1637, check)
      call createCurrent(P_GMinus, P_Hl, P_WPlus, P_Z, 1016, check)
      call createCurrent(P_WPlus, P_G0, P_GMinus, P_A, 134, check)
      call createCurrent(P_A, P_Hh, P_Hl, P_Z, 1432, check)
      call createCurrent(P_Hl, P_GPlus, P_Z, P_WMinus, 82, check)
      call createCurrent(P_Z, P_GMinus, P_WPlus, P_Hl, 477, check)
      call createCurrent(P_muPlus, P_muMinus, P_Z, 125, check)
      call createCurrent(P_ghWpAnti, P_G0, P_ghWp, 806, check)
      call createCurrent(P_Hl, P_Z, P_A, 1495, check)
      call createCurrent(P_g, P_dAnti, P_d, 756, check)
      call createCurrent(P_GMinus, P_t, P_bAnti, 557, check)
      call createCurrent(P_Hl, P_Hh, P_WPlus, P_WMinus, 435, check)
      call createCurrent(P_d, P_Z, P_dAnti, 798, check)
      call createCurrent(P_bAnti, P_GMinus, P_t, 633, check)
      call createCurrent(P_Z, P_Z, P_WMinus, P_WPlus, 1117, check)
      call createCurrent(P_Hl, P_GMinus, P_WPlus, 424, check)
      call createCurrent(P_t, P_A, P_tAnti, 180, check)
      call createCurrent(P_G0, P_Z, P_G0, P_A, 1441, check)
      call createCurrent(P_WMinus, P_Hl, P_Hl, P_WPlus, 537, check)
      call createCurrent(P_Z, P_A, P_Hh, 1415, check)
      call createCurrent(P_A, P_WMinus, P_Hh, P_GPlus, 412, check)
      call createCurrent(P_GMinus, P_sAnti, P_c, 317, check)
      call createCurrent(P_WPlus, P_Z, P_GMinus, P_Hl, 917, check)
      call createCurrent(P_Hl, P_Hh, P_Hh, P_Hl, 354, check)
      call createCurrent(P_A, P_tauMinus, P_tauPlus, 250, check)
      call createCurrent(P_Hl, P_ePlus, P_eMinus, 1039, check)
      call createCurrent(P_WPlus, P_Hl, P_WMinus, P_Hl, 1297, check)
      call createCurrent(P_Hl, P_WPlus, P_WMinus, P_Hh, 931, check)
      call createCurrent(P_WPlus, P_A, P_GMinus, P_Hh, 845, check)
      call createCurrent(P_WMinus, P_GPlus, P_Z, P_G0, 7, check)
      call createCurrent(P_WMinus, P_GPlus, P_G0, 1012, check)
      call createCurrent(P_A, P_G0, P_GMinus, P_WPlus, 46, check)
      call createCurrent(P_Z, P_Hh, P_GMinus, P_WPlus, 838, check)
      call createCurrent(P_G0, P_Z, P_A, P_G0, 1528, check)
      call createCurrent(P_A, P_Z, P_Hl, P_Hh, 1515, check)
      call createCurrent(P_Hl, P_Hh, P_GMinus, P_GPlus, 639, check)
      call createCurrent(P_Z, P_GPlus, P_A, P_GMinus, 1241, check)
      call createCurrent(P_WMinus, P_G0, P_GPlus, P_Z, 160, check)
      call createCurrent(P_g, P_WPlus, P_g, P_WMinus, 1566, check)
      call createCurrent(P_GMinus, P_Hh, P_A, P_WPlus, 605, check)
      call createCurrent(P_Hl, P_Z, P_Hl, P_A, 1430, check)
      call createCurrent(P_dAnti, P_G0, P_d, 1234, check)
      call createCurrent(P_tauPlus, P_tauMinus, P_Z, 1343, check)
      call createCurrent(P_A, P_GPlus, P_Hl, P_WMinus, 459, check)
      call createCurrent(P_g, P_ghGAnti, P_ghG, 296, check)
      call createCurrent(P_ghWm, P_G0, P_ghWmAnti, 1079, check)
      call createCurrent(P_muMinus, P_muPlus, P_Z, 663, check)
      call createCurrent(P_eMinus, P_Z, P_ePlus, 1370, check)
      call createCurrent(P_Hh, P_muPlus, P_muMinus, 313, check)
      call createCurrent(P_WPlus, P_cAnti, P_s, 1249, check)
      call createCurrent(P_Hh, P_t, P_tAnti, 609, check)
      call createCurrent(P_Hh, P_Hh, P_A, P_Z, 1468, check)
      call createCurrent(P_tAnti, P_g, P_t, 133, check)
      call createCurrent(P_cAnti, P_G0, P_c, 943, check)
      call createCurrent(P_ghZ, P_GPlus, P_ghWpAnti, 238, check)
      call createCurrent(P_WMinus, P_WMinus, P_WPlus, P_WPlus, 297, check)
      call createCurrent(P_tAnti, P_t, P_Hh, 518, check)
      call createCurrent(P_GPlus, P_Z, P_Hl, P_WMinus, 430, check)
      call createCurrent(P_GMinus, P_GPlus, P_Hh, P_Hh, 108, check)
      call createCurrent(P_GPlus, P_GMinus, P_Z, P_A, 1011, check)
      call createCurrent(P_ghWmAnti, P_ghWm, P_Hl, 1220, check)
      call createCurrent(P_GPlus, P_WMinus, P_G0, P_Z, 1240, check)
      call createCurrent(P_Hh, P_Hl, P_G0, P_G0, 490, check)
      call createCurrent(P_GPlus, P_Z, P_WMinus, P_Hh, 287, check)
      call createCurrent(P_Hh, P_g, P_g, P_Hl, 1558, check)
      call createCurrent(P_A, P_WPlus, P_A, P_WMinus, 1137, check)
      call createCurrent(P_GMinus, P_GPlus, P_WMinus, P_WPlus, 1376, check)
      call createCurrent(P_g, P_Hh, P_Hh, P_g, 1607, check)
      call createCurrent(P_WMinus, P_Hl, P_GPlus, P_Z, 742, check)
      call createCurrent(P_GPlus, P_GMinus, P_Hl, P_Hl, 632, check)
      call createCurrent(P_G0, P_ePlus, P_eMinus, 494, check)
      call createCurrent(P_G0, P_G0, P_g, P_g, 1586, check)
      call createCurrent(P_g, P_G0, P_G0, P_g, 1642, check)
      call createCurrent(P_Hl, P_muPlus, P_muMinus, 1301, check)
      call createCurrent(P_GPlus, P_WMinus, P_Hl, P_Z, 138, check)
      call createCurrent(P_WMinus, P_WPlus, P_GMinus, P_GPlus, 420, check)
    end subroutine createCurrents

    subroutine check_vertices_mdl()
      call createCurrents(.true.)
    end subroutine check_vertices_mdl

    subroutine get_vertex_lorentz_rank_mdl(ty,cc,mr)
      integer, intent(in) :: ty
      logical, intent(in) :: cc(0:)
      integer, intent(out) :: mr
      select case(ty)
      case(9)
        if (cc(0)) then
          mr = 1
        else
          mr = 0
        end if 
      case(13)
        if (cc(0)) then
          mr = 1
        else
          mr = 0
        end if 
      case(14)
        if (cc(0) .or. cc(1)) then
          mr = 1
        else
          mr = 0
        end if 
      case(15)
        if (cc(0)) then
          mr = 1
        else
          mr = 0
        end if 
      case(16)
        if (cc(0) .or. cc(1)) then
          mr = 1
        else
          mr = 0
        end if 
      case(17)
        if (cc(0)) then
          mr = 1
        else
          mr = 0
        end if 
      case(18)
        if (cc(0)) then
          mr = 1
        else
          mr = 0
        end if 
      case(24)
        if (cc(0) .or. cc(1)) then
          mr = 1
        else
          mr = 0
        end if 
      case(25)
        if (cc(0)) then
          mr = 1
        else
          mr = 0
        end if 
      case(26)
        if (cc(0)) then
          mr = 1
        else
          mr = 0
        end if 
      case(31)
        if (cc(0) .or. cc(1)) then
          mr = 1
        else
          mr = 0
        end if 
      case(32)
        if (cc(0)) then
          mr = 1
        else
          mr = 0
        end if 
      case(33)
        if (cc(0)) then
          mr = 1
        else
          mr = 0
        end if 
      case(48)
        if (cc(0) .or. cc(1)) then
          mr = 1
        else
          mr = 0
        end if 
      case(49)
        if (cc(0)) then
          mr = 1
        else
          mr = 0
        end if 
      case(50)
        if (cc(0)) then
          mr = 1
        else
          mr = 0
        end if 
      case(51)
        if (cc(0)) then
          mr = 1
        else
          mr = 0
        end if 
      case(52)
        if (cc(0) .or. cc(1)) then
          mr = 1
        else
          mr = 0
        end if 
      case(53)
        if (cc(0)) then
          mr = 1
        else
          mr = 0
        end if 
      case(54)
        if (cc(0)) then
          mr = 1
        else
          mr = 0
        end if 
      case(56)
        if (cc(0) .or. cc(1)) then
          mr = 1
        else
          mr = 0
        end if 
      case(57)
        if (cc(0)) then
          mr = 1
        else
          mr = 0
        end if 
      case(58)
        if (cc(0)) then
          mr = 1
        else
          mr = 0
        end if 
      case(59)
        if (cc(0)) then
          mr = 1
        else
          mr = 0
        end if 
      case(63)
        if (cc(0)) then
          mr = 1
        else
          mr = 0
        end if 
      case(70)
        if (cc(0)) then
          mr = 1
        else
          mr = 0
        end if 
      case(74)
        if (cc(0)) then
          mr = 1
        else
          mr = 0
        end if 
      case(77)
        if (cc(0) .or. cc(1)) then
          mr = 1
        else
          mr = 0
        end if 
      case(78)
        if (cc(0)) then
          mr = 1
        else
          mr = 0
        end if 
      case(80)
        if (cc(0)) then
          mr = 1
        else
          mr = 0
        end if 
      case default
        mr = 0
      end select 
    end subroutine get_vertex_lorentz_rank_mdl
end module class_vertices
